/****************************************************************************
** Meta object code from reading C++ file 'dccscreen.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/dccscreen.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccscreen.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513DccScreenItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccScreenItem::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513DccScreenItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccScreenItem",
        "brightnessChanged",
        "",
        "nameChanged",
        "canBrightness",
        "brightness",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'canBrightness'
        QtMocHelpers::MethodData<bool() const>(4, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'brightness'
        QtMocHelpers::PropertyData<double>(5, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccScreenItem, qt_meta_tag_ZN6dccV2513DccScreenItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccScreenItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DccScreenItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DccScreenItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513DccScreenItemE_t>.metaTypes,
    nullptr
} };

void dccV25::DccScreenItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccScreenItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brightnessChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: { bool _r = _t->canBrightness();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccScreenItem::*)()>(_a, &DccScreenItem::brightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreenItem::*)()>(_a, &DccScreenItem::nameChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->brightness(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBrightness(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccScreenItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccScreenItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DccScreenItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccScreenItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccScreenItem::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::DccScreenItem::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN6dccV259DccScreenE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccScreen::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV259DccScreenE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccScreen",
        "nameChanged",
        "",
        "enableChanged",
        "xChanged",
        "yChanged",
        "widthChanged",
        "heightChanged",
        "bestResolutionChanged",
        "currentResolutionChanged",
        "resolutionListChanged",
        "bestRateChanged",
        "currentRateChanged",
        "rateListChanged",
        "rotateChanged",
        "brightnessChanged",
        "currentModeChanged",
        "currentFillModeChanged",
        "availableFillModesChanged",
        "screenChanged",
        "scaleChanged",
        "maxScaleChanged",
        "screenItemsChanged",
        "wallpaperChanged",
        "name",
        "enable",
        "x",
        "y",
        "width",
        "height",
        "bestResolution",
        "QSize",
        "currentResolution",
        "resolutionList",
        "QList<QSize>",
        "bestRate",
        "currentRate",
        "rateList",
        "QList<double>",
        "brightness",
        "rotate",
        "currentFillMode",
        "availableFillModes",
        "screen",
        "QScreen*",
        "scale",
        "maxScale",
        "screenItems",
        "QList<DccScreenItem*>",
        "wallpaper"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bestResolutionChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentResolutionChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resolutionListChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bestRateChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentRateChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rateListChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotateChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModeChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentFillModeChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableFillModesChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxScaleChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenItemsChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'enable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'x'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'y'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'width'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'height'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'bestResolution'
        QtMocHelpers::PropertyData<QSize>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'currentResolution'
        QtMocHelpers::PropertyData<QSize>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'resolutionList'
        QtMocHelpers::PropertyData<QList<QSize>>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 8),
        // property 'bestRate'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'currentRate'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10),
        // property 'rateList'
        QtMocHelpers::PropertyData<QList<double>>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 11),
        // property 'brightness'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Final, 13),
        // property 'rotate'
        QtMocHelpers::PropertyData<uint>(40, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 12),
        // property 'currentFillMode'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 15),
        // property 'availableFillModes'
        QtMocHelpers::PropertyData<QStringList>(42, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 16),
        // property 'screen'
        QtMocHelpers::PropertyData<QScreen*>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 17),
        // property 'scale'
        QtMocHelpers::PropertyData<qreal>(45, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 18),
        // property 'maxScale'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 19),
        // property 'screenItems'
        QtMocHelpers::PropertyData<QList<DccScreenItem*>>(47, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 20),
        // property 'wallpaper'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccScreen, qt_meta_tag_ZN6dccV259DccScreenE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DccScreen::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccScreenE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccScreenE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV259DccScreenE_t>.metaTypes,
    nullptr
} };

void dccV25::DccScreen::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccScreen *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->enableChanged(); break;
        case 2: _t->xChanged(); break;
        case 3: _t->yChanged(); break;
        case 4: _t->widthChanged(); break;
        case 5: _t->heightChanged(); break;
        case 6: _t->bestResolutionChanged(); break;
        case 7: _t->currentResolutionChanged(); break;
        case 8: _t->resolutionListChanged(); break;
        case 9: _t->bestRateChanged(); break;
        case 10: _t->currentRateChanged(); break;
        case 11: _t->rateListChanged(); break;
        case 12: _t->rotateChanged(); break;
        case 13: _t->brightnessChanged(); break;
        case 14: _t->currentModeChanged(); break;
        case 15: _t->currentFillModeChanged(); break;
        case 16: _t->availableFillModesChanged(); break;
        case 17: _t->screenChanged(); break;
        case 18: _t->scaleChanged(); break;
        case 19: _t->maxScaleChanged(); break;
        case 20: _t->screenItemsChanged(); break;
        case 21: _t->wallpaperChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::enableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::xChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::yChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::widthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::heightChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::bestResolutionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::currentResolutionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::resolutionListChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::bestRateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::currentRateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::rateListChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::rotateChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::brightnessChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::currentModeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::currentFillModeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::availableFillModesChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::screenChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::scaleChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::maxScaleChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::screenItemsChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccScreen::*)()>(_a, &DccScreen::wallpaperChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<DccScreenItem*> >(); break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<double> >(); break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->y(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 6: *reinterpret_cast<QSize*>(_v) = _t->bestResolution(); break;
        case 7: *reinterpret_cast<QSize*>(_v) = _t->currentResolution(); break;
        case 8: *reinterpret_cast<QList<QSize>*>(_v) = _t->resolutionList(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->bestRate(); break;
        case 10: *reinterpret_cast<double*>(_v) = _t->currentRate(); break;
        case 11: *reinterpret_cast<QList<double>*>(_v) = _t->rateList(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->brightness(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->rotate(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->currentFillMode(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->availableFillModes(); break;
        case 16: *reinterpret_cast<QScreen**>(_v) = _t->screen(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->scale(); break;
        case 18: *reinterpret_cast<qreal*>(_v) = _t->maxScale(); break;
        case 19: *reinterpret_cast<QList<DccScreenItem*>*>(_v) = _t->screenItems(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->wallpaper(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 7: _t->setCurrentResolution(*reinterpret_cast<QSize*>(_v)); break;
        case 10: _t->setCurrentRate(*reinterpret_cast<double*>(_v)); break;
        case 13: _t->setRotate(*reinterpret_cast<uint*>(_v)); break;
        case 14: _t->setCurrentFillMode(*reinterpret_cast<QString*>(_v)); break;
        case 17: _t->setScale(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccScreen::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccScreen::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259DccScreenE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DccScreen::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccScreen::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::DccScreen::enableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::DccScreen::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dccV25::DccScreen::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dccV25::DccScreen::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dccV25::DccScreen::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dccV25::DccScreen::bestResolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dccV25::DccScreen::currentResolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dccV25::DccScreen::resolutionListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dccV25::DccScreen::bestRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void dccV25::DccScreen::currentRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dccV25::DccScreen::rateListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dccV25::DccScreen::rotateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void dccV25::DccScreen::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dccV25::DccScreen::currentModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void dccV25::DccScreen::currentFillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void dccV25::DccScreen::availableFillModesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void dccV25::DccScreen::screenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void dccV25::DccScreen::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void dccV25::DccScreen::maxScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void dccV25::DccScreen::screenItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void dccV25::DccScreen::wallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
