/****************************************************************************
** Meta object code from reading C++ file 'userdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/userdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'userdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13UserDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto UserDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN13UserDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UserDBusProxy",
        "AccountTypeChanged",
        "",
        "value",
        "AutomaticLoginChanged",
        "CreatedTimeChanged",
        "DesktopBackgroundsChanged",
        "FullNameChanged",
        "GidChanged",
        "GreeterBackgroundChanged",
        "GroupsChanged",
        "HistoryLayoutChanged",
        "HomeDirChanged",
        "IconFileChanged",
        "IconListChanged",
        "LayoutChanged",
        "LocaleChanged",
        "LockedChanged",
        "LoginTimeChanged",
        "LongDateFormatChanged",
        "LongTimeFormatChanged",
        "MaxPasswordAgeChanged",
        "NoPasswdLoginChanged",
        "PasswordHintChanged",
        "PasswordLastChangeChanged",
        "PasswordStatusChanged",
        "ShellChanged",
        "ShortDateFormatChanged",
        "ShortTimeFormatChanged",
        "SystemAccountChanged",
        "UidChanged",
        "UUIDChanged",
        "Use24HourFormatChanged",
        "UserNameChanged",
        "WeekBeginsChanged",
        "WeekdayFormatChanged",
        "XSessionChanged",
        "QuickLoginChanged",
        "WechatAuthChanged",
        "AddGroup",
        "QDBusPendingReply<>",
        "group",
        "DeleteGroup",
        "DeleteIconFile",
        "iconFile",
        "EnableNoPasswdLogin",
        "enabled",
        "IsPasswordExpired",
        "QDBusPendingReply<bool>",
        "SetAutomaticLogin",
        "SetDesktopBackgrounds",
        "backgrounds",
        "SetFullName",
        "name",
        "SetGreeterBackground",
        "background",
        "SetGroups",
        "groups",
        "SetHistoryLayout",
        "layouts",
        "SetHomeDir",
        "home",
        "SetIconFile",
        "SetLayout",
        "layout",
        "SetLocale",
        "locale",
        "SetLocked",
        "locked",
        "SetMaxPasswordAge",
        "nDays",
        "SetPassword",
        "password",
        "SetPasswordHint",
        "hint",
        "SetShell",
        "shell",
        "GetSecretQuestions",
        "QDBusPendingReply<QList<int>>",
        "SetSecretQuestions",
        "QMap<int,QByteArray>",
        "securityQuestions",
        "SetQuickLogin",
        "EnableWechatAuth",
        "onPropertiesChanged",
        "QDBusMessage",
        "message",
        "AccountType",
        "AutomaticLogin",
        "CreatedTime",
        "DesktopBackgrounds",
        "FullName",
        "Gid",
        "GreeterBackground",
        "Groups",
        "HistoryLayout",
        "HomeDir",
        "IconFile",
        "IconList",
        "Layout",
        "Locale",
        "Locked",
        "LoginTime",
        "LongDateFormat",
        "LongTimeFormat",
        "MaxPasswordAge",
        "NoPasswdLogin",
        "PasswordHint",
        "PasswordLastChange",
        "PasswordStatus",
        "Shell",
        "ShortDateFormat",
        "ShortTimeFormat",
        "SystemAccount",
        "Uid",
        "UUID",
        "Use24HourFormat",
        "UserName",
        "WeekBegins",
        "WeekdayFormat",
        "XSession",
        "QuickLogin",
        "WechatAuthEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AccountTypeChanged'
        QtMocHelpers::SignalData<void(int) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'AutomaticLoginChanged'
        QtMocHelpers::SignalData<void(bool) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'CreatedTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'DesktopBackgroundsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'FullNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'GidChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'GreeterBackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'GroupsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'HistoryLayoutChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'HomeDirChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'IconFileChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'IconListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'LayoutChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'LocaleChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'LockedChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'LoginTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Signal 'LongDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'LongTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'MaxPasswordAgeChanged'
        QtMocHelpers::SignalData<void(int) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'NoPasswdLoginChanged'
        QtMocHelpers::SignalData<void(bool) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'PasswordHintChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'PasswordLastChangeChanged'
        QtMocHelpers::SignalData<void(int) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'PasswordStatusChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ShellChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ShortDateFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'ShortTimeFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'SystemAccountChanged'
        QtMocHelpers::SignalData<void(bool) const>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'UidChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'UUIDChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'Use24HourFormatChanged'
        QtMocHelpers::SignalData<void(bool) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'UserNameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'WeekBeginsChanged'
        QtMocHelpers::SignalData<void(int) const>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'WeekdayFormatChanged'
        QtMocHelpers::SignalData<void(int) const>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'XSessionChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'QuickLoginChanged'
        QtMocHelpers::SignalData<void(bool) const>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'WechatAuthChanged'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'AddGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'DeleteGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'DeleteIconFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(43, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'EnableNoPasswdLogin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(45, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'IsPasswordExpired'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(47, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'SetAutomaticLogin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(49, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'SetDesktopBackgrounds'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(50, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QStringList, 51 },
        }}),
        // Slot 'SetFullName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'SetGreeterBackground'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(54, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 55 },
        }}),
        // Slot 'SetGroups'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(56, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QStringList, 57 },
        }}),
        // Slot 'SetHistoryLayout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(58, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QStringList, 59 },
        }}),
        // Slot 'SetHomeDir'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(60, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'SetIconFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(62, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'SetLayout'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(63, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'SetLocale'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(65, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'SetLocked'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(67, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Bool, 68 },
        }}),
        // Slot 'SetMaxPasswordAge'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(69, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Int, 70 },
        }}),
        // Slot 'SetPassword'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(71, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 72 },
        }}),
        // Slot 'SetPasswordHint'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(73, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 74 },
        }}),
        // Slot 'SetShell'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(75, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::QString, 76 },
        }}),
        // Slot 'GetSecretQuestions'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int>>()>(77, 2, QMC::AccessPublic, 0x80000000 | 78),
        // Slot 'SetSecretQuestions'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QMap<int,QByteArray> &)>(79, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Slot 'SetQuickLogin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(82, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'EnableWechatAuth'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(83, 2, QMC::AccessPublic, 0x80000000 | 40, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 85, 86 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AccountType'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'AutomaticLogin'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'CreatedTime'
        QtMocHelpers::PropertyData<qulonglong>(89, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 2),
        // property 'DesktopBackgrounds'
        QtMocHelpers::PropertyData<QStringList>(90, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'FullName'
        QtMocHelpers::PropertyData<QString>(91, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'Gid'
        QtMocHelpers::PropertyData<QString>(92, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'GreeterBackground'
        QtMocHelpers::PropertyData<QString>(93, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'Groups'
        QtMocHelpers::PropertyData<QStringList>(94, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'HistoryLayout'
        QtMocHelpers::PropertyData<QStringList>(95, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'HomeDir'
        QtMocHelpers::PropertyData<QString>(96, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'IconFile'
        QtMocHelpers::PropertyData<QString>(97, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'IconList'
        QtMocHelpers::PropertyData<QStringList>(98, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
        // property 'Layout'
        QtMocHelpers::PropertyData<QString>(99, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'Locale'
        QtMocHelpers::PropertyData<QString>(100, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'LoginTime'
        QtMocHelpers::PropertyData<qulonglong>(102, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 15),
        // property 'LongDateFormat'
        QtMocHelpers::PropertyData<int>(103, QMetaType::Int, QMC::DefaultPropertyFlags, 16),
        // property 'LongTimeFormat'
        QtMocHelpers::PropertyData<int>(104, QMetaType::Int, QMC::DefaultPropertyFlags, 17),
        // property 'MaxPasswordAge'
        QtMocHelpers::PropertyData<int>(105, QMetaType::Int, QMC::DefaultPropertyFlags, 18),
        // property 'NoPasswdLogin'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'PasswordHint'
        QtMocHelpers::PropertyData<QString>(107, QMetaType::QString, QMC::DefaultPropertyFlags, 20),
        // property 'PasswordLastChange'
        QtMocHelpers::PropertyData<int>(108, QMetaType::Int, QMC::DefaultPropertyFlags, 21),
        // property 'PasswordStatus'
        QtMocHelpers::PropertyData<QString>(109, QMetaType::QString, QMC::DefaultPropertyFlags, 22),
        // property 'Shell'
        QtMocHelpers::PropertyData<QString>(110, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
        // property 'ShortDateFormat'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags, 24),
        // property 'ShortTimeFormat'
        QtMocHelpers::PropertyData<int>(112, QMetaType::Int, QMC::DefaultPropertyFlags, 25),
        // property 'SystemAccount'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags, 26),
        // property 'Uid'
        QtMocHelpers::PropertyData<QString>(114, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'UUID'
        QtMocHelpers::PropertyData<QString>(115, QMetaType::QString, QMC::DefaultPropertyFlags, 28),
        // property 'Use24HourFormat'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags, 29),
        // property 'UserName'
        QtMocHelpers::PropertyData<QString>(117, QMetaType::QString, QMC::DefaultPropertyFlags, 30),
        // property 'WeekBegins'
        QtMocHelpers::PropertyData<int>(118, QMetaType::Int, QMC::DefaultPropertyFlags, 31),
        // property 'WeekdayFormat'
        QtMocHelpers::PropertyData<int>(119, QMetaType::Int, QMC::DefaultPropertyFlags, 32),
        // property 'XSession'
        QtMocHelpers::PropertyData<QString>(120, QMetaType::QString, QMC::DefaultPropertyFlags, 33),
        // property 'QuickLogin'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags, 34),
        // property 'WechatAuthEnabled'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags, 35),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UserDBusProxy, qt_meta_tag_ZN13UserDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UserDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UserDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UserDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13UserDBusProxyE_t>.metaTypes,
    nullptr
} };

void UserDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UserDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AccountTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->AutomaticLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->CreatedTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->DesktopBackgroundsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->FullNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->GidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->GreeterBackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->GroupsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->HistoryLayoutChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 9: _t->HomeDirChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->IconFileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->IconListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->LayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->LocaleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->LockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->LoginTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 16: _t->LongDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->LongTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->MaxPasswordAgeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->NoPasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->PasswordHintChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->PasswordLastChangeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->PasswordStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->ShellChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->ShortDateFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->ShortTimeFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->SystemAccountChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->UidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->UUIDChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->Use24HourFormatChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->UserNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->WeekBeginsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->WeekdayFormatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->XSessionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->QuickLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->WechatAuthChanged(); break;
        case 36: { QDBusPendingReply<> _r = _t->AddGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->DeleteGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->DeleteIconFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->EnableNoPasswdLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<bool> _r = _t->IsPasswordExpired();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->SetAutomaticLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<> _r = _t->SetDesktopBackgrounds((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<> _r = _t->SetFullName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<> _r = _t->SetGreeterBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 45: { QDBusPendingReply<> _r = _t->SetGroups((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<> _r = _t->SetHistoryLayout((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<> _r = _t->SetHomeDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<> _r = _t->SetIconFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDBusPendingReply<> _r = _t->SetLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 50: { QDBusPendingReply<> _r = _t->SetLocale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 51: { QDBusPendingReply<> _r = _t->SetLocked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 52: { QDBusPendingReply<> _r = _t->SetMaxPasswordAge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 53: { QDBusPendingReply<> _r = _t->SetPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 54: { QDBusPendingReply<> _r = _t->SetPasswordHint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 55: { QDBusPendingReply<> _r = _t->SetShell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 56: { QDBusPendingReply<QList<int>> _r = _t->GetSecretQuestions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 57: { QDBusPendingReply<> _r = _t->SetSecretQuestions((*reinterpret_cast<std::add_pointer_t<QMap<int,QByteArray>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 58: { QDBusPendingReply<> _r = _t->SetQuickLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 59: { QDBusPendingReply<> _r = _t->EnableWechatAuth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 60:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::AccountTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::AutomaticLoginChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(qulonglong ) const>(_a, &UserDBusProxy::CreatedTimeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QStringList & ) const>(_a, &UserDBusProxy::DesktopBackgroundsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::FullNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::GidChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::GreeterBackgroundChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QStringList & ) const>(_a, &UserDBusProxy::GroupsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QStringList & ) const>(_a, &UserDBusProxy::HistoryLayoutChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::HomeDirChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::IconFileChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QStringList & ) const>(_a, &UserDBusProxy::IconListChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::LayoutChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::LocaleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::LockedChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(qulonglong ) const>(_a, &UserDBusProxy::LoginTimeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::LongDateFormatChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::LongTimeFormatChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::MaxPasswordAgeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::NoPasswdLoginChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::PasswordHintChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::PasswordLastChangeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::PasswordStatusChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::ShellChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::ShortDateFormatChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::ShortTimeFormatChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::SystemAccountChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::UidChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::UUIDChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::Use24HourFormatChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::UserNameChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::WeekBeginsChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(int ) const>(_a, &UserDBusProxy::WeekdayFormatChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(const QString & ) const>(_a, &UserDBusProxy::XSessionChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)(bool ) const>(_a, &UserDBusProxy::QuickLoginChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserDBusProxy::*)()>(_a, &UserDBusProxy::WechatAuthChanged, 35))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->accountType(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->automaticLogin(); break;
        case 2: *reinterpret_cast<qulonglong*>(_v) = _t->createdTime(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->desktopBackgrounds(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->fullName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->gid(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->greeterBackground(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->groups(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->historyLayout(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->homeDir(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->iconFile(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->iconList(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->layout(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->locale(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 15: *reinterpret_cast<qulonglong*>(_v) = _t->loginTime(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->longDateFormat(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->longTimeFormat(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->maxPasswordAge(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->noPasswdLogin(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->passwordHint(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->passwordLastChange(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->passwordStatus(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->shell(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->shortDateFormat(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->shortTimeFormat(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->systemAccount(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->use24HourFormat(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->userName(); break;
        case 31: *reinterpret_cast<int*>(_v) = _t->weekBegins(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->weekdayFormat(); break;
        case 33: *reinterpret_cast<QString*>(_v) = _t->xSession(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->quickLogin(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->wechatAuth(); break;
        default: break;
        }
    }
}

const QMetaObject *UserDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UserDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13UserDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UserDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void UserDBusProxy::AccountTypeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UserDBusProxy::AutomaticLoginChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UserDBusProxy::CreatedTimeChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UserDBusProxy::DesktopBackgroundsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UserDBusProxy::FullNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UserDBusProxy::GidChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UserDBusProxy::GreeterBackgroundChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void UserDBusProxy::GroupsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void UserDBusProxy::HistoryLayoutChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UserDBusProxy::HomeDirChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UserDBusProxy::IconFileChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void UserDBusProxy::IconListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void UserDBusProxy::LayoutChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void UserDBusProxy::LocaleChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void UserDBusProxy::LockedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void UserDBusProxy::LoginTimeChanged(qulonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void UserDBusProxy::LongDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void UserDBusProxy::LongTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void UserDBusProxy::MaxPasswordAgeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void UserDBusProxy::NoPasswdLoginChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void UserDBusProxy::PasswordHintChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void UserDBusProxy::PasswordLastChangeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void UserDBusProxy::PasswordStatusChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void UserDBusProxy::ShellChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void UserDBusProxy::ShortDateFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void UserDBusProxy::ShortTimeFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void UserDBusProxy::SystemAccountChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void UserDBusProxy::UidChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void UserDBusProxy::UUIDChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void UserDBusProxy::Use24HourFormatChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void UserDBusProxy::UserNameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void UserDBusProxy::WeekBeginsChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void UserDBusProxy::WeekdayFormatChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void UserDBusProxy::XSessionChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void UserDBusProxy::QuickLoginChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< UserDBusProxy *>(this), &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void UserDBusProxy::WechatAuthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}
QT_WARNING_POP
