#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_deepin_dcc_Crumb_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccCheckIcon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccEditorItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccGroupView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccItemBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccMenuEditorItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccMenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccRightView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccRowView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccSettingsObject_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccSettingsView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccTimeRange_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccTitleObject_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccUtils_js { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_DccWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_HomePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_SearchBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_deepin_dcc_SecondPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/Crumb.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_Crumb_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccCheckIcon.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccCheckIcon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccEditorItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccEditorItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccGroupView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccGroupView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccItemBackground.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccItemBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccMenuEditorItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccMenuEditorItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccMenuItem.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccMenuItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccRightView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccRightView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccRowView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccRowView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccSettingsObject.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccSettingsObject_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccSettingsView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccSettingsView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccTimeRange.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccTimeRange_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccTitleObject.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccTitleObject_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccUtils.js"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccUtils_js::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/DccWindow.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_DccWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/HomePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_HomePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/SearchBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_SearchBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/deepin/dcc/SecondPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_deepin_dcc_SecondPage_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_dde_control_center_lib)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_dde_control_center_lib))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_dde_control_center_lib)() {
    return 1;
}
