/****************************************************************************
** Meta object code from reading C++ file 'port.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-sound/operation/port.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'port.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4PortE_t {};
} // unnamed namespace

template <> constexpr inline auto Port::qt_create_metaobjectdata<qt_meta_tag_ZN4PortE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Port",
        "idChanged",
        "",
        "id",
        "nameChanged",
        "name",
        "cardNameChanged",
        "isInputActiveChanged",
        "active",
        "isOutputActiveChanged",
        "directionChanged",
        "Direction",
        "direction",
        "cardIdChanged",
        "cardId",
        "currentPortEnabled",
        "enable",
        "currentBluetoothPortChanged",
        "isBlue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void(QString) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(QString) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cardNameChanged'
        QtMocHelpers::SignalData<void(QString) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'isInputActiveChanged'
        QtMocHelpers::SignalData<void(bool) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'isOutputActiveChanged'
        QtMocHelpers::SignalData<void(bool) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'directionChanged'
        QtMocHelpers::SignalData<void(enum Direction) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'cardIdChanged'
        QtMocHelpers::SignalData<void(uint) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Signal 'currentPortEnabled'
        QtMocHelpers::SignalData<void(bool) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'currentBluetoothPortChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Port, qt_meta_tag_ZN4PortE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Port::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PortE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PortE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4PortE_t>.metaTypes,
    nullptr
} };

void Port::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Port *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cardNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->isInputActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->isOutputActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->directionChanged((*reinterpret_cast<std::add_pointer_t<enum Direction>>(_a[1]))); break;
        case 6: _t->cardIdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->currentPortEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->currentBluetoothPortChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Port::*)(QString ) const>(_a, &Port::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(QString ) const>(_a, &Port::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(QString ) const>(_a, &Port::cardNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(bool ) const>(_a, &Port::isInputActiveChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(bool ) const>(_a, &Port::isOutputActiveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(Direction ) const>(_a, &Port::directionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(uint ) const>(_a, &Port::cardIdChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(bool ) const>(_a, &Port::currentPortEnabled, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Port::*)(bool ) const>(_a, &Port::currentBluetoothPortChanged, 8))
            return;
    }
}

const QMetaObject *Port::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Port::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PortE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Port::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Port::idChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Port::nameChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Port::cardNameChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Port::isInputActiveChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Port::isOutputActiveChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Port::directionChanged(Direction _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Port::cardIdChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Port::currentPortEnabled(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Port::currentBluetoothPortChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< Port *>(this), &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
