/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<dccmodel.h>)
#  include <dccmodel.h>
#endif
#if __has_include(<dccobject.h>)
#  include <dccobject.h>
#endif
#if __has_include(<dccquickdbusinterface.h>)
#  include <dccquickdbusinterface.h>
#endif
#if __has_include(<dccquickrepeater.h>)
#  include <dccquickrepeater.h>
#endif
#if __has_include(<dccrepeater.h>)
#  include <dccrepeater.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_dcc()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<dccV25::DccModel>("org.deepin.dcc", 1);
    qmlRegisterAnonymousType<QAbstractItemModel, 254>("org.deepin.dcc", 1);
    qmlRegisterTypesAndRevisions<dccV25::DccObject>("org.deepin.dcc", 1);
    qmlRegisterEnum<dccV25::DccObject::BackgroundTypes>("dccV25::DccObject::BackgroundTypes");
    qmlRegisterEnum<dccV25::DccObject::BackgroundType>("dccV25::DccObject::BackgroundType");
    qmlRegisterEnum<dccV25::DccObject::PageType>("dccV25::DccObject::PageType");
    qmlRegisterTypesAndRevisions<dccV25::DccQuickDBusInterface>("org.deepin.dcc", 1);
    qmlRegisterEnum<dccV25::DccQuickDBusInterface::BusType>("dccV25::DccQuickDBusInterface::BusType");
    qmlRegisterTypesAndRevisions<dccV25::DccQuickRepeater>("org.deepin.dcc", 1);
    qmlRegisterAnonymousType<QQuickRepeater, 254>("org.deepin.dcc", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.deepin.dcc", 1);
    qmlRegisterTypesAndRevisions<dccV25::DccRepeater>("org.deepin.dcc", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.deepin.dcc", 1, 0);
}

static const QQmlModuleRegistration orgdeepindccRegistration("org.deepin.dcc", qml_register_types_org_deepin_dcc);
