/****************************************************************************
** Meta object code from reading C++ file 'dccmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../dde-control-center/src/dde-control-center/plugin/dccmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV258DccModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DccModel::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV258DccModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DccModel",
        "QML.Element",
        "auto",
        "rootChanged",
        "",
        "DccObject*",
        "root",
        "setRoot",
        "getObject",
        "row",
        "updateObject",
        "AboutToAddObject",
        "const DccObject*",
        "parent",
        "pos",
        "addObject",
        "child",
        "AboutToRemoveObject",
        "removeObject",
        "AboutToMoveObject",
        "oldPos",
        "moveObject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rootChanged'
        QtMocHelpers::SignalData<void(DccObject *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setRoot'
        QtMocHelpers::SlotData<void(DccObject *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'getObject'
        QtMocHelpers::SlotData<DccObject *(int)>(8, 4, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'updateObject'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AboutToAddObject'
        QtMocHelpers::SlotData<void(const DccObject *, int)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'addObject'
        QtMocHelpers::SlotData<void(const DccObject *)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 16 },
        }}),
        // Slot 'AboutToRemoveObject'
        QtMocHelpers::SlotData<void(const DccObject *, int)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'removeObject'
        QtMocHelpers::SlotData<void(const DccObject *)>(18, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 16 },
        }}),
        // Slot 'AboutToMoveObject'
        QtMocHelpers::SlotData<void(const DccObject *, int, int)>(19, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'moveObject'
        QtMocHelpers::SlotData<void(const DccObject *)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'root'
        QtMocHelpers::PropertyData<DccObject*>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DccModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject dccV25::DccModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV258DccModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV258DccModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV258DccModelE_t>.metaTypes,
    nullptr
} };

void dccV25::DccModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rootChanged((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 1: _t->setRoot((*reinterpret_cast<std::add_pointer_t<DccObject*>>(_a[1]))); break;
        case 2: { DccObject* _r = _t->getObject((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DccObject**>(_a[0]) = std::move(_r); }  break;
        case 3: _t->updateObject(); break;
        case 4: _t->AboutToAddObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->addObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1]))); break;
        case 6: _t->AboutToRemoveObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->removeObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1]))); break;
        case 8: _t->AboutToMoveObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->moveObject((*reinterpret_cast<std::add_pointer_t<const DccObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccModel::*)(DccObject * )>(_a, &DccModel::rootChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DccObject**>(_v) = _t->root(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRoot(*reinterpret_cast<DccObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DccModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DccModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV258DccModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int dccV25::DccModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DccModel::rootChanged(DccObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
