/****************************************************************************
** Meta object code from reading C++ file 'bluetoothmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-bluetooth/operation/bluetoothmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14BluetoothModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothModel::qt_create_metaobjectdata<qt_meta_tag_ZN14BluetoothModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothModel",
        "QML.Element",
        "QML.Singleton",
        "true",
        "adapterAdded",
        "",
        "const BluetoothAdapter*",
        "adapter",
        "adapterRemoved",
        "adpaterListChanged",
        "transportableChanged",
        "transPortable",
        "canSendFileChanged",
        "canSendFile",
        "airplaneEnableChanged",
        "enable",
        "displaySwitchChanged",
        "on",
        "showBluetoothChanged",
        "addAdapter",
        "BluetoothAdapter*",
        "removeAdapater",
        "adapterId",
        "setTransportable",
        "setCanSendFile",
        "setAirplaneEnable",
        "setDisplaySwitch",
        "blueToothAdaptersModel",
        "BlueToothAdaptersModel*",
        "displaySwitch",
        "airplaneEnable",
        "showBluetooth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'adapterAdded'
        QtMocHelpers::SignalData<void(const BluetoothAdapter *) const>(4, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(const BluetoothAdapter *) const>(8, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'adpaterListChanged'
        QtMocHelpers::SignalData<void()>(9, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transportableChanged'
        QtMocHelpers::SignalData<void(const bool) const>(10, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'canSendFileChanged'
        QtMocHelpers::SignalData<void(const bool) const>(12, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'airplaneEnableChanged'
        QtMocHelpers::SignalData<void(bool) const>(14, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'displaySwitchChanged'
        QtMocHelpers::SignalData<void(bool) const>(16, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'showBluetoothChanged'
        QtMocHelpers::SignalData<void()>(18, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addAdapter'
        QtMocHelpers::SlotData<void(BluetoothAdapter *)>(19, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 7 },
        }}),
        // Slot 'removeAdapater'
        QtMocHelpers::SlotData<const BluetoothAdapter *(const QString &)>(21, 5, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setTransportable'
        QtMocHelpers::SlotData<void(const bool)>(23, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setCanSendFile'
        QtMocHelpers::SlotData<void(const bool)>(24, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setAirplaneEnable'
        QtMocHelpers::SlotData<void(bool)>(25, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setDisplaySwitch'
        QtMocHelpers::SlotData<void(bool)>(26, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'blueToothAdaptersModel'
        QtMocHelpers::MethodData<BlueToothAdaptersModel *() const>(27, 5, QMC::AccessPublic, 0x80000000 | 28),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'displaySwitch'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 6),
        // property 'airplaneEnable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'showBluetooth'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<BluetoothModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BluetoothModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BluetoothModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BluetoothModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14BluetoothModelE_t>.metaTypes,
    nullptr
} };

void BluetoothModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->adapterAdded((*reinterpret_cast<std::add_pointer_t<const BluetoothAdapter*>>(_a[1]))); break;
        case 1: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<const BluetoothAdapter*>>(_a[1]))); break;
        case 2: _t->adpaterListChanged(); break;
        case 3: _t->transportableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->canSendFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->airplaneEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->displaySwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->showBluetoothChanged(); break;
        case 8: _t->addAdapter((*reinterpret_cast<std::add_pointer_t<BluetoothAdapter*>>(_a[1]))); break;
        case 9: { const BluetoothAdapter* _r = _t->removeAdapater((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<const BluetoothAdapter**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setTransportable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setCanSendFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setAirplaneEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setDisplaySwitch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: { BlueToothAdaptersModel* _r = _t->blueToothAdaptersModel();
            if (_a[0]) *reinterpret_cast<BlueToothAdaptersModel**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BluetoothAdapter* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(const BluetoothAdapter * ) const>(_a, &BluetoothModel::adapterAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(const BluetoothAdapter * ) const>(_a, &BluetoothModel::adapterRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)()>(_a, &BluetoothModel::adpaterListChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(const bool ) const>(_a, &BluetoothModel::transportableChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(const bool ) const>(_a, &BluetoothModel::canSendFileChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(bool ) const>(_a, &BluetoothModel::airplaneEnableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)(bool ) const>(_a, &BluetoothModel::displaySwitchChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothModel::*)()>(_a, &BluetoothModel::showBluetoothChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->displaySwitch(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->airplaneEnable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showBluetooth(); break;
        default: break;
        }
    }
}

const QMetaObject *BluetoothModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14BluetoothModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluetoothModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void BluetoothModel::adapterAdded(const BluetoothAdapter * _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluetoothModel::adapterRemoved(const BluetoothAdapter * _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluetoothModel::adpaterListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BluetoothModel::transportableChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluetoothModel::canSendFileChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluetoothModel::airplaneEnableChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluetoothModel::displaySwitchChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothModel *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluetoothModel::showBluetoothChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
