/****************************************************************************
** Meta object code from reading C++ file 'wallpaperprovider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/wallpaperprovider.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wallpaperprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15InterfaceWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto InterfaceWorker::qt_create_metaobjectdata<qt_meta_tag_ZN15InterfaceWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InterfaceWorker",
        "pushBackground",
        "",
        "QList<WallpaperItemPtr>",
        "items",
        "WallpaperType",
        "type",
        "pushOneBackground",
        "WallpaperItemPtr",
        "listFinished",
        "startListBackground",
        "startListOne",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pushBackground'
        QtMocHelpers::SignalData<void(const QList<WallpaperItemPtr> &, WallpaperType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'pushBackground'
        QtMocHelpers::SignalData<void(const QList<WallpaperItemPtr> &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'pushOneBackground'
        QtMocHelpers::SignalData<void(const WallpaperItemPtr, WallpaperType)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'pushOneBackground'
        QtMocHelpers::SignalData<void(const WallpaperItemPtr)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'listFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startListBackground'
        QtMocHelpers::SlotData<void(WallpaperType)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'startListBackground'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'startListOne'
        QtMocHelpers::SlotData<void(const QString &, WallpaperType)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'startListOne'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InterfaceWorker, qt_meta_tag_ZN15InterfaceWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InterfaceWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15InterfaceWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15InterfaceWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15InterfaceWorkerE_t>.metaTypes,
    nullptr
} };

void InterfaceWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InterfaceWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pushBackground((*reinterpret_cast<std::add_pointer_t<QList<WallpaperItemPtr>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[2]))); break;
        case 1: _t->pushBackground((*reinterpret_cast<std::add_pointer_t<QList<WallpaperItemPtr>>>(_a[1]))); break;
        case 2: _t->pushOneBackground((*reinterpret_cast<std::add_pointer_t<WallpaperItemPtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[2]))); break;
        case 3: _t->pushOneBackground((*reinterpret_cast<std::add_pointer_t<WallpaperItemPtr>>(_a[1]))); break;
        case 4: _t->listFinished(); break;
        case 5: _t->startListBackground((*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[1]))); break;
        case 6: _t->startListBackground(); break;
        case 7: _t->startListOne((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[2]))); break;
        case 8: _t->startListOne((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InterfaceWorker::*)(const QList<WallpaperItemPtr> & , WallpaperType )>(_a, &InterfaceWorker::pushBackground, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InterfaceWorker::*)(const WallpaperItemPtr , WallpaperType )>(_a, &InterfaceWorker::pushOneBackground, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InterfaceWorker::*)()>(_a, &InterfaceWorker::listFinished, 4))
            return;
    }
}

const QMetaObject *InterfaceWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InterfaceWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15InterfaceWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InterfaceWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void InterfaceWorker::pushBackground(const QList<WallpaperItemPtr> & _t1, WallpaperType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void InterfaceWorker::pushOneBackground(const WallpaperItemPtr _t1, WallpaperType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 4
void InterfaceWorker::listFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN17WallpaperProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto WallpaperProvider::qt_create_metaobjectdata<qt_meta_tag_ZN17WallpaperProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WallpaperProvider",
        "fetchFinish",
        "",
        "setWallpaper",
        "QList<WallpaperItemPtr>",
        "items",
        "WallpaperType",
        "type",
        "pushWallpaper",
        "WallpaperItemPtr",
        "item",
        "onWallpaperChangedFromDaemon",
        "user",
        "mode",
        "paths"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fetchFinish'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QList<WallpaperItemPtr> &, WallpaperType)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QList<WallpaperItemPtr> &)>(3, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'pushWallpaper'
        QtMocHelpers::SlotData<void(WallpaperItemPtr, WallpaperType)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'pushWallpaper'
        QtMocHelpers::SlotData<void(WallpaperItemPtr)>(8, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onWallpaperChangedFromDaemon'
        QtMocHelpers::SlotData<void(const QString &, uint, const QStringList &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 13 }, { QMetaType::QStringList, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperProvider, qt_meta_tag_ZN17WallpaperProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WallpaperProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WallpaperProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WallpaperProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17WallpaperProviderE_t>.metaTypes,
    nullptr
} };

void WallpaperProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fetchFinish(); break;
        case 1: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QList<WallpaperItemPtr>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[2]))); break;
        case 2: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QList<WallpaperItemPtr>>>(_a[1]))); break;
        case 3: _t->pushWallpaper((*reinterpret_cast<std::add_pointer_t<WallpaperItemPtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WallpaperType>>(_a[2]))); break;
        case 4: _t->pushWallpaper((*reinterpret_cast<std::add_pointer_t<WallpaperItemPtr>>(_a[1]))); break;
        case 5: _t->onWallpaperChangedFromDaemon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperProvider::*)()>(_a, &WallpaperProvider::fetchFinish, 0))
            return;
    }
}

const QMetaObject *WallpaperProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WallpaperProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17WallpaperProviderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WallpaperProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void WallpaperProvider::fetchFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
