//SPDX-FileCopyrightText: 2025 - 2026 UnionTech Software Technology Co., Ltd.
//
//SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#include <QObject>

class PersonalizationExport : public QObject
{
    Q_OBJECT
public:
    PersonalizationExport(QObject *parent = nullptr)
    : QObject(parent)
    {

    }
    enum WallpaperSetOption {
        Option_Desktop = 0,
        Option_Lock,
        Option_Other,
        Option_All,
    };
    Q_ENUM(WallpaperSetOption)

    enum ModuleType {
        Root = 0,
        Theme,
        Wallpaper,
        ScreenSaver
    };

    Q_ENUM(ModuleType)

    enum WallpaperType {
        Type_Image,
        Type_Video
    };

    Q_ENUM(WallpaperType)
};
