// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>


QT_DECLARE_EXTERN_RESOURCE(qmlcache_dde_control_center_lib)
QT_DECLARE_EXTERN_RESOURCE(qmake_org_deepin_dcc)
QT_DECLARE_EXTERN_RESOURCE(dde_control_center_lib_raw_qml_0)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_org_deepin_dcc)

class org_deepin_dccPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    org_deepin_dccPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_org_deepin_dcc)
QT_KEEP_RESOURCE(qmlcache_dde_control_center_lib)
QT_KEEP_RESOURCE(qmake_org_deepin_dcc)
QT_KEEP_RESOURCE(dde_control_center_lib_raw_qml_0)
    }
};



#include "dde-control-center-lib_org_deepin_dccPlugin.moc"
