/****************************************************************************
** Meta object code from reading C++ file 'bluetoothdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-bluetooth/operation/bluetoothdevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15BluetoothDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothDevice::qt_create_metaobjectdata<qt_meta_tag_ZN15BluetoothDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothDevice",
        "nameChanged",
        "",
        "name",
        "aliasChanged",
        "alias",
        "pairedChanged",
        "paired",
        "stateChanged",
        "State",
        "state",
        "trustedChanged",
        "trusted",
        "connectingChanged",
        "connecting",
        "batteryChanged",
        "battery",
        "StateUnavailable",
        "StateAvailable",
        "StateConnected",
        "StateDisconnecting"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'aliasChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'pairedChanged'
        QtMocHelpers::SignalData<void(const bool &) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(const State &, bool) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'trustedChanged'
        QtMocHelpers::SignalData<void(const bool) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'connectingChanged'
        QtMocHelpers::SignalData<void(const bool &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'batteryChanged'
        QtMocHelpers::SignalData<void(const int) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(9, 9, QMC::EnumFlags{}).add({
            {   17, State::StateUnavailable },
            {   18, State::StateAvailable },
            {   19, State::StateConnected },
            {   20, State::StateDisconnecting },
        }),
    };
    return QtMocHelpers::metaObjectData<BluetoothDevice, qt_meta_tag_ZN15BluetoothDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluetoothDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BluetoothDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BluetoothDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15BluetoothDeviceE_t>.metaTypes,
    nullptr
} };

void BluetoothDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->aliasChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->pairedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<enum State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->trustedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->connectingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->batteryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const QString & ) const>(_a, &BluetoothDevice::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const QString & ) const>(_a, &BluetoothDevice::aliasChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const bool & ) const>(_a, &BluetoothDevice::pairedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const State & , bool ) const>(_a, &BluetoothDevice::stateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const bool ) const>(_a, &BluetoothDevice::trustedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const bool & ) const>(_a, &BluetoothDevice::connectingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)(const int ) const>(_a, &BluetoothDevice::batteryChanged, 6))
            return;
    }
}

const QMetaObject *BluetoothDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BluetoothDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluetoothDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void BluetoothDevice::nameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluetoothDevice::aliasChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluetoothDevice::pairedChanged(const bool & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluetoothDevice::stateChanged(const State & _t1, bool _t2)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void BluetoothDevice::trustedChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluetoothDevice::connectingChanged(const bool & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluetoothDevice::batteryChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothDevice *>(this), &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
