/****************************************************************************
** Meta object code from reading C++ file 'notificationmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-notification/operation/notificationmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::NotificationModel::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::NotificationModel",
        "appListAdded",
        "",
        "AppItemModel*",
        "item",
        "appListRemoved",
        "appItemModelsChanged",
        "appAdded",
        "appRemoved",
        "appName",
        "appListModel",
        "AppsListModel*",
        "sysItemModel",
        "SysItemModel*",
        "appItemModels",
        "QList<AppItemModel*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appListAdded'
        QtMocHelpers::SignalData<void(AppItemModel *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'appListRemoved'
        QtMocHelpers::SignalData<void(AppItemModel *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'appItemModelsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appAdded'
        QtMocHelpers::SlotData<void(AppItemModel *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'appRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'appListModel'
        QtMocHelpers::MethodData<AppsListModel *()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sysItemModel'
        QtMocHelpers::PropertyData<SysItemModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'appItemModels'
        QtMocHelpers::PropertyData<QList<AppItemModel*>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationModel, qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::NotificationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::NotificationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appListAdded((*reinterpret_cast<std::add_pointer_t<AppItemModel*>>(_a[1]))); break;
        case 1: _t->appListRemoved((*reinterpret_cast<std::add_pointer_t<AppItemModel*>>(_a[1]))); break;
        case 2: _t->appItemModelsChanged(); break;
        case 3: _t->appAdded((*reinterpret_cast<std::add_pointer_t<AppItemModel*>>(_a[1]))); break;
        case 4: _t->appRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { AppsListModel* _r = _t->appListModel();
            if (_a[0]) *reinterpret_cast<AppsListModel**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)(AppItemModel * )>(_a, &NotificationModel::appListAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)(AppItemModel * )>(_a, &NotificationModel::appListRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)()>(_a, &NotificationModel::appItemModelsChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<SysItemModel**>(_v) = _t->sysItemModel(); break;
        case 1: *reinterpret_cast<QList<AppItemModel*>*>(_v) = _t->appItemModels(); break;
        default: break;
        }
    }
}

const QMetaObject *DCC_NAMESPACE::NotificationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::NotificationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE17NotificationModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::NotificationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::NotificationModel::appListAdded(AppItemModel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::NotificationModel::appListRemoved(AppItemModel * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::NotificationModel::appItemModelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
