// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_appinfolistmodel.cpp"
#include "MTJHVBGFB2/moc_deepiniddbusproxy.cpp"
#include "MTJHVBGFB2/moc_deepinidinterface.cpp"
#include "MTJHVBGFB2/moc_deepinidmodel.cpp"
#include "MTJHVBGFB2/moc_deepinidworker.cpp"
#include "MTJHVBGFB2/moc_downloadurl.cpp"
#include "MTJHVBGFB2/moc_syncdbusproxy.cpp"
#include "MTJHVBGFB2/moc_syncinfolistmodel.cpp"
#include "MTJHVBGFB2/moc_utclouddbusproxy.cpp"
