/****************************************************************************
** Meta object code from reading C++ file 'deepinidmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-deepinid/operation/deepinidmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'deepinidmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DeepinidModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DeepinidModel::qt_create_metaobjectdata<qt_meta_tag_ZN13DeepinidModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeepinidModel",
        "loginStateChanged",
        "",
        "loginState",
        "avatarChanged",
        "avatar",
        "regionChanged",
        "region",
        "userNameChanged",
        "userName",
        "wechatNameChanged",
        "wechatName",
        "syncEnabledChanged",
        "enable",
        "syncSwitchChanged",
        "syncItemShowChanged",
        "show",
        "syncStateChanged",
        "std::pair<qint32,QString>",
        "syncState",
        "lastSyncTimeChanged",
        "lastSyncTime",
        "updateAvatarPath",
        "syncInfoListModel",
        "SyncInfoListModel*",
        "appInfoListModel",
        "AppInfoListModel*",
        "warnTipsMessage",
        "syncEnabled",
        "syncSwitch",
        "syncItemShow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loginStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'avatarChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'regionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'userNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'wechatNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'syncEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'syncSwitchChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'syncItemShowChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'syncStateChanged'
        QtMocHelpers::SignalData<void(const std::pair<qint32,QString> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'lastSyncTimeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'updateAvatarPath'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Method 'syncInfoListModel'
        QtMocHelpers::MethodData<SyncInfoListModel *() const>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Method 'appInfoListModel'
        QtMocHelpers::MethodData<AppInfoListModel *() const>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Method 'warnTipsMessage'
        QtMocHelpers::MethodData<QString()>(27, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loginState'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'avatar'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'region'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'userName'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'wechatName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'syncEnabled'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'syncSwitch'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'syncItemShow'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'lastSyncTime'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeepinidModel, qt_meta_tag_ZN13DeepinidModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeepinidModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinidModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinidModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DeepinidModelE_t>.metaTypes,
    nullptr
} };

void DeepinidModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeepinidModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loginStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->avatarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->regionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->userNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->wechatNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->syncEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->syncSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->syncItemShowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->syncStateChanged((*reinterpret_cast<std::add_pointer_t<std::pair<qint32,QString>>>(_a[1]))); break;
        case 9: _t->lastSyncTimeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->updateAvatarPath(); break;
        case 11: { SyncInfoListModel* _r = _t->syncInfoListModel();
            if (_a[0]) *reinterpret_cast<SyncInfoListModel**>(_a[0]) = std::move(_r); }  break;
        case 12: { AppInfoListModel* _r = _t->appInfoListModel();
            if (_a[0]) *reinterpret_cast<AppInfoListModel**>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->warnTipsMessage();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(bool )>(_a, &DeepinidModel::loginStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const QString & )>(_a, &DeepinidModel::avatarChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const QString & )>(_a, &DeepinidModel::regionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const QString & )>(_a, &DeepinidModel::userNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const QString & )>(_a, &DeepinidModel::wechatNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(bool )>(_a, &DeepinidModel::syncEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(bool )>(_a, &DeepinidModel::syncSwitchChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(bool )>(_a, &DeepinidModel::syncItemShowChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const std::pair<qint32,QString> & )>(_a, &DeepinidModel::syncStateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinidModel::*)(const QString & )>(_a, &DeepinidModel::lastSyncTimeChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->getLoginState(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getAvatar(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->getRegion(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->getUserName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->getWechatName(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->syncEnabled(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->syncSwitch(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->syncItemShow(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->lastSyncTime(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setSyncSwitch(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setSyncItemShow(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeepinidModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeepinidModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinidModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeepinidModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void DeepinidModel::loginStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeepinidModel::avatarChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeepinidModel::regionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeepinidModel::userNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeepinidModel::wechatNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeepinidModel::syncEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeepinidModel::syncSwitchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeepinidModel::syncItemShowChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeepinidModel::syncStateChanged(const std::pair<qint32,QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeepinidModel::lastSyncTimeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
