/****************************************************************************
** Meta object code from reading C++ file 'displaymodule.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/displaymodule.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displaymodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513DisplayModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DisplayModule::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513DisplayModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DisplayModule",
        "virtualScreensChanged",
        "",
        "screensChanged",
        "primaryScreenChanged",
        "displayModeChanged",
        "isX11Changed",
        "globalScaleChanged",
        "globalScaleEnabledChanged",
        "maxGlobalScaleChanged",
        "colorTemperatureEnabledChanged",
        "colorTemperatureModeChanged",
        "colorTemperatureChanged",
        "customColorTempTimePeriodChanged",
        "wallpaperChanged",
        "saveChanges",
        "resetBackup",
        "adsorptionScreen",
        "QList<QObject*>",
        "listItems",
        "pw",
        "scale",
        "executemultiScreenAlgo",
        "applySettings",
        "applyChanged",
        "virtualScreens",
        "QList<DccScreen*>",
        "screens",
        "primaryScreen",
        "DccScreen*",
        "displayMode",
        "isX11",
        "globalScale",
        "maxGlobalScale",
        "colorTemperatureEnabled",
        "colorTemperatureMode",
        "colorTemperature",
        "customColorTempTimePeriod"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'virtualScreensChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screensChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'primaryScreenChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayModeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isX11Changed'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalScaleChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalScaleEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxGlobalScaleChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorTemperatureEnabledChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorTemperatureModeChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorTemperatureChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customColorTempTimePeriodChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveChanges'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetBackup'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adsorptionScreen'
        QtMocHelpers::SlotData<void(QList<QObject*>, QObject *, qreal)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QObjectStar, 20 }, { QMetaType::QReal, 21 },
        }}),
        // Slot 'executemultiScreenAlgo'
        QtMocHelpers::SlotData<void(QList<QObject*>, QObject *, qreal)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QObjectStar, 20 }, { QMetaType::QReal, 21 },
        }}),
        // Slot 'applySettings'
        QtMocHelpers::SlotData<void(QList<QObject*>, qreal)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QReal, 21 },
        }}),
        // Slot 'applyChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'virtualScreens'
        QtMocHelpers::PropertyData<QList<DccScreen*>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'screens'
        QtMocHelpers::PropertyData<QList<DccScreen*>>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'primaryScreen'
        QtMocHelpers::PropertyData<DccScreen*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'displayMode'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'isX11'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'globalScale'
        QtMocHelpers::PropertyData<qreal>(32, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'maxGlobalScale'
        QtMocHelpers::PropertyData<qreal>(33, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 7),
        // property 'colorTemperatureEnabled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'colorTemperatureMode'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9),
        // property 'colorTemperature'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10),
        // property 'customColorTempTimePeriod'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisplayModule, qt_meta_tag_ZN6dccV2513DisplayModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DisplayModule::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513DisplayModuleE_t>.metaTypes,
    nullptr
} };

void dccV25::DisplayModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->virtualScreensChanged(); break;
        case 1: _t->screensChanged(); break;
        case 2: _t->primaryScreenChanged(); break;
        case 3: _t->displayModeChanged(); break;
        case 4: _t->isX11Changed(); break;
        case 5: _t->globalScaleChanged(); break;
        case 6: _t->globalScaleEnabledChanged(); break;
        case 7: _t->maxGlobalScaleChanged(); break;
        case 8: _t->colorTemperatureEnabledChanged(); break;
        case 9: _t->colorTemperatureModeChanged(); break;
        case 10: _t->colorTemperatureChanged(); break;
        case 11: _t->customColorTempTimePeriodChanged(); break;
        case 12: _t->wallpaperChanged(); break;
        case 13: _t->saveChanges(); break;
        case 14: _t->resetBackup(); break;
        case 15: _t->adsorptionScreen((*reinterpret_cast<std::add_pointer_t<QList<QObject*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 16: _t->executemultiScreenAlgo((*reinterpret_cast<std::add_pointer_t<QList<QObject*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3]))); break;
        case 17: _t->applySettings((*reinterpret_cast<std::add_pointer_t<QList<QObject*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 18: _t->applyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QObject*> >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QObject*> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QObject*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::virtualScreensChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::screensChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::primaryScreenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::displayModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::isX11Changed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::globalScaleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::globalScaleEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::maxGlobalScaleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::colorTemperatureEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::colorTemperatureModeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::colorTemperatureChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::customColorTempTimePeriodChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModule::*)()>(_a, &DisplayModule::wallpaperChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<DccScreen*>*>(_v) = _t->virtualScreens(); break;
        case 1: *reinterpret_cast<QList<DccScreen*>*>(_v) = _t->screens(); break;
        case 2: *reinterpret_cast<DccScreen**>(_v) = _t->primaryScreen(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->displayMode(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isX11(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->globalScale(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->maxGlobalScale(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->colorTemperatureEnabled(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->colorTemperatureMode(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->colorTemperature(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->customColorTempTimePeriod(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setPrimaryScreen(*reinterpret_cast<DccScreen**>(_v)); break;
        case 3: _t->setDisplayMode(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setGlobalScale(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setColorTemperatureEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setColorTemperatureMode(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setColorTemperature(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setCustomColorTempTimePeriod(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::DisplayModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DisplayModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513DisplayModuleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DisplayModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DisplayModule::virtualScreensChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::DisplayModule::screensChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dccV25::DisplayModule::primaryScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dccV25::DisplayModule::displayModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dccV25::DisplayModule::isX11Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dccV25::DisplayModule::globalScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dccV25::DisplayModule::globalScaleEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dccV25::DisplayModule::maxGlobalScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dccV25::DisplayModule::colorTemperatureEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dccV25::DisplayModule::colorTemperatureModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void dccV25::DisplayModule::colorTemperatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dccV25::DisplayModule::customColorTempTimePeriodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dccV25::DisplayModule::wallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
