/****************************************************************************
** Meta object code from reading C++ file 'monitordbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/private/monitordbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitordbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16MonitorDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto MonitorDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN16MonitorDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonitorDBusProxy",
        "AvailableFillModesChanged",
        "",
        "value",
        "BestModeChanged",
        "Resolution",
        "ConnectedChanged",
        "CurrentFillModeChanged",
        "CurrentModeChanged",
        "CurrentRotateModeChanged",
        "EnabledChanged",
        "HeightChanged",
        "ManufacturerChanged",
        "MmHeightChanged",
        "MmWidthChanged",
        "ModelChanged",
        "ModesChanged",
        "ResolutionList",
        "NameChanged",
        "ReflectChanged",
        "ReflectsChanged",
        "ReflectList",
        "RefreshRateChanged",
        "RotationChanged",
        "RotationsChanged",
        "RotationList",
        "WidthChanged",
        "XChanged",
        "YChanged",
        "Enable",
        "QDBusPendingReply<>",
        "in0",
        "SetMode",
        "SetModeBySize",
        "in1",
        "SetPosition",
        "SetReflect",
        "SetRotation",
        "onPropertiesChanged",
        "QDBusMessage",
        "message",
        "AvailableFillModes",
        "BestMode",
        "Connected",
        "CurrentFillMode",
        "CurrentMode",
        "CurrentRotateMode",
        "Enabled",
        "Height",
        "Manufacturer",
        "MmHeight",
        "MmWidth",
        "Model",
        "Modes",
        "Name",
        "Reflect",
        "Reflects",
        "RefreshRate",
        "Rotation",
        "Rotations",
        "Width",
        "X",
        "Y"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AvailableFillModesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'BestModeChanged'
        QtMocHelpers::SignalData<void(Resolution) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 3 },
        }}),
        // Signal 'ConnectedChanged'
        QtMocHelpers::SignalData<void(bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'CurrentFillModeChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CurrentModeChanged'
        QtMocHelpers::SignalData<void(Resolution) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 3 },
        }}),
        // Signal 'CurrentRotateModeChanged'
        QtMocHelpers::SignalData<void(uchar) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 3 },
        }}),
        // Signal 'EnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'HeightChanged'
        QtMocHelpers::SignalData<void(ushort) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 3 },
        }}),
        // Signal 'ManufacturerChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'MmHeightChanged'
        QtMocHelpers::SignalData<void(uint) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'MmWidthChanged'
        QtMocHelpers::SignalData<void(uint) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'ModelChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ModesChanged'
        QtMocHelpers::SignalData<void(ResolutionList) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 3 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ReflectChanged'
        QtMocHelpers::SignalData<void(ushort) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 3 },
        }}),
        // Signal 'ReflectsChanged'
        QtMocHelpers::SignalData<void(ReflectList) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 3 },
        }}),
        // Signal 'RefreshRateChanged'
        QtMocHelpers::SignalData<void(double) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Signal 'RotationChanged'
        QtMocHelpers::SignalData<void(ushort) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 3 },
        }}),
        // Signal 'RotationsChanged'
        QtMocHelpers::SignalData<void(RotationList) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 3 },
        }}),
        // Signal 'WidthChanged'
        QtMocHelpers::SignalData<void(ushort) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 3 },
        }}),
        // Signal 'XChanged'
        QtMocHelpers::SignalData<void(short) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Short, 3 },
        }}),
        // Signal 'YChanged'
        QtMocHelpers::SignalData<void(short) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Short, 3 },
        }}),
        // Slot 'Enable'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'SetMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(32, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::UInt, 31 },
        }}),
        // Slot 'SetModeBySize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(ushort, ushort)>(33, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::UShort, 31 }, { QMetaType::UShort, 34 },
        }}),
        // Slot 'SetPosition'
        QtMocHelpers::SlotData<QDBusPendingReply<>(short, short)>(35, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Short, 31 }, { QMetaType::Short, 34 },
        }}),
        // Slot 'SetReflect'
        QtMocHelpers::SlotData<QDBusPendingReply<>(ushort)>(36, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::UShort, 31 },
        }}),
        // Slot 'SetRotation'
        QtMocHelpers::SlotData<QDBusPendingReply<>(ushort)>(37, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::UShort, 31 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AvailableFillModes'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'BestMode'
        QtMocHelpers::PropertyData<Resolution>(42, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'Connected'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'CurrentFillMode'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'CurrentMode'
        QtMocHelpers::PropertyData<Resolution>(45, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'CurrentRotateMode'
        QtMocHelpers::PropertyData<uchar>(46, QMetaType::UChar, QMC::DefaultPropertyFlags, 5),
        // property 'Enabled'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'Height'
        QtMocHelpers::PropertyData<ushort>(48, QMetaType::UShort, QMC::DefaultPropertyFlags, 7),
        // property 'Manufacturer'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'MmHeight'
        QtMocHelpers::PropertyData<uint>(50, QMetaType::UInt, QMC::DefaultPropertyFlags, 9),
        // property 'MmWidth'
        QtMocHelpers::PropertyData<uint>(51, QMetaType::UInt, QMC::DefaultPropertyFlags, 10),
        // property 'Model'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'Modes'
        QtMocHelpers::PropertyData<ResolutionList>(53, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'Reflect'
        QtMocHelpers::PropertyData<ushort>(55, QMetaType::UShort, QMC::DefaultPropertyFlags, 14),
        // property 'Reflects'
        QtMocHelpers::PropertyData<ReflectList>(56, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'RefreshRate'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags, 16),
        // property 'Rotation'
        QtMocHelpers::PropertyData<ushort>(58, QMetaType::UShort, QMC::DefaultPropertyFlags, 17),
        // property 'Rotations'
        QtMocHelpers::PropertyData<RotationList>(59, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'Width'
        QtMocHelpers::PropertyData<ushort>(60, QMetaType::UShort, QMC::DefaultPropertyFlags, 19),
        // property 'X'
        QtMocHelpers::PropertyData<short>(61, QMetaType::Short, QMC::DefaultPropertyFlags, 20),
        // property 'Y'
        QtMocHelpers::PropertyData<short>(62, QMetaType::Short, QMC::DefaultPropertyFlags, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonitorDBusProxy, qt_meta_tag_ZN16MonitorDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MonitorDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MonitorDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MonitorDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16MonitorDBusProxyE_t>.metaTypes,
    nullptr
} };

void MonitorDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonitorDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AvailableFillModesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->BestModeChanged((*reinterpret_cast<std::add_pointer_t<Resolution>>(_a[1]))); break;
        case 2: _t->ConnectedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->CurrentFillModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->CurrentModeChanged((*reinterpret_cast<std::add_pointer_t<Resolution>>(_a[1]))); break;
        case 5: _t->CurrentRotateModeChanged((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1]))); break;
        case 6: _t->EnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->HeightChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 8: _t->ManufacturerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->MmHeightChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: _t->MmWidthChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 11: _t->ModelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->ModesChanged((*reinterpret_cast<std::add_pointer_t<ResolutionList>>(_a[1]))); break;
        case 13: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->ReflectChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 15: _t->ReflectsChanged((*reinterpret_cast<std::add_pointer_t<ReflectList>>(_a[1]))); break;
        case 16: _t->RefreshRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->RotationChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 18: _t->RotationsChanged((*reinterpret_cast<std::add_pointer_t<RotationList>>(_a[1]))); break;
        case 19: _t->WidthChanged((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1]))); break;
        case 20: _t->XChanged((*reinterpret_cast<std::add_pointer_t<short>>(_a[1]))); break;
        case 21: _t->YChanged((*reinterpret_cast<std::add_pointer_t<short>>(_a[1]))); break;
        case 22: { QDBusPendingReply<> _r = _t->Enable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetMode((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->SetModeBySize((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ushort>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->SetPosition((*reinterpret_cast<std::add_pointer_t<short>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<short>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->SetReflect((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->SetRotation((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Resolution >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Resolution >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(const QStringList & ) const>(_a, &MonitorDBusProxy::AvailableFillModesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(Resolution ) const>(_a, &MonitorDBusProxy::BestModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(bool ) const>(_a, &MonitorDBusProxy::ConnectedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(const QString & ) const>(_a, &MonitorDBusProxy::CurrentFillModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(Resolution ) const>(_a, &MonitorDBusProxy::CurrentModeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(uchar ) const>(_a, &MonitorDBusProxy::CurrentRotateModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(bool ) const>(_a, &MonitorDBusProxy::EnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ushort ) const>(_a, &MonitorDBusProxy::HeightChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(const QString & ) const>(_a, &MonitorDBusProxy::ManufacturerChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(uint ) const>(_a, &MonitorDBusProxy::MmHeightChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(uint ) const>(_a, &MonitorDBusProxy::MmWidthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(const QString & ) const>(_a, &MonitorDBusProxy::ModelChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ResolutionList ) const>(_a, &MonitorDBusProxy::ModesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(const QString & ) const>(_a, &MonitorDBusProxy::NameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ushort ) const>(_a, &MonitorDBusProxy::ReflectChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ReflectList ) const>(_a, &MonitorDBusProxy::ReflectsChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(double ) const>(_a, &MonitorDBusProxy::RefreshRateChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ushort ) const>(_a, &MonitorDBusProxy::RotationChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(RotationList ) const>(_a, &MonitorDBusProxy::RotationsChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(ushort ) const>(_a, &MonitorDBusProxy::WidthChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(short ) const>(_a, &MonitorDBusProxy::XChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorDBusProxy::*)(short ) const>(_a, &MonitorDBusProxy::YChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Resolution >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->availableFillModes(); break;
        case 1: *reinterpret_cast<Resolution*>(_v) = _t->bestMode(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->currentFillMode(); break;
        case 4: *reinterpret_cast<Resolution*>(_v) = _t->currentMode(); break;
        case 5: *reinterpret_cast<uchar*>(_v) = _t->currentRotateMode(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 7: *reinterpret_cast<ushort*>(_v) = _t->height(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->manufacturer(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->mmHeight(); break;
        case 10: *reinterpret_cast<uint*>(_v) = _t->mmWidth(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 12: *reinterpret_cast<ResolutionList*>(_v) = _t->modes(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 14: *reinterpret_cast<ushort*>(_v) = _t->reflect(); break;
        case 15: *reinterpret_cast<ReflectList*>(_v) = _t->reflects(); break;
        case 16: *reinterpret_cast<double*>(_v) = _t->refreshRate(); break;
        case 17: *reinterpret_cast<ushort*>(_v) = _t->rotation(); break;
        case 18: *reinterpret_cast<RotationList*>(_v) = _t->rotations(); break;
        case 19: *reinterpret_cast<ushort*>(_v) = _t->width(); break;
        case 20: *reinterpret_cast<short*>(_v) = _t->x(); break;
        case 21: *reinterpret_cast<short*>(_v) = _t->y(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setCurrentFillMode(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MonitorDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MonitorDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MonitorDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MonitorDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void MonitorDBusProxy::AvailableFillModesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MonitorDBusProxy::BestModeChanged(Resolution _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MonitorDBusProxy::ConnectedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MonitorDBusProxy::CurrentFillModeChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MonitorDBusProxy::CurrentModeChanged(Resolution _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MonitorDBusProxy::CurrentRotateModeChanged(uchar _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MonitorDBusProxy::EnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MonitorDBusProxy::HeightChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void MonitorDBusProxy::ManufacturerChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void MonitorDBusProxy::MmHeightChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void MonitorDBusProxy::MmWidthChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void MonitorDBusProxy::ModelChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void MonitorDBusProxy::ModesChanged(ResolutionList _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void MonitorDBusProxy::NameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void MonitorDBusProxy::ReflectChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void MonitorDBusProxy::ReflectsChanged(ReflectList _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void MonitorDBusProxy::RefreshRateChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void MonitorDBusProxy::RotationChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void MonitorDBusProxy::RotationsChanged(RotationList _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void MonitorDBusProxy::WidthChanged(ushort _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void MonitorDBusProxy::XChanged(short _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void MonitorDBusProxy::YChanged(short _t1)const
{
    QMetaObject::activate<void>(const_cast< MonitorDBusProxy *>(this), &staticMetaObject, 21, nullptr, _t1);
}
QT_WARNING_POP
