/****************************************************************************
** Meta object code from reading C++ file 'Registry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/wayland/libwayqt/Registry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Registry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3WQt8RegistryE_t {};
} // unnamed namespace

template <> constexpr inline auto WQt::Registry::qt_create_metaobjectdata<qt_meta_tag_ZN3WQt8RegistryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WQt::Registry",
        "errorOccured",
        "",
        "ErrorType",
        "et",
        "outputAdded",
        "WQt::Output*",
        "outputRemoved",
        "interfaceRegistered",
        "WQt::Registry::Interface",
        "interfaceDeregistered",
        "EmptyShm",
        "EmptyIdle",
        "EmptySeat",
        "EmptyXdgWmBase",
        "EmptyCompositor",
        "EmptyOutputManager",
        "EmptyTreeLandOuputManager",
        "Interface",
        "ShmInterface",
        "IdleInterface",
        "SeatInterface",
        "WlrIdleInterface",
        "XdgWmBaseInterface",
        "CompositorInterface",
        "OutputManagerInterface",
        "TreeLandOutputManagerInterface"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'errorOccured'
        QtMocHelpers::SignalData<void(enum ErrorType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'outputAdded'
        QtMocHelpers::SignalData<void(WQt::Output *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'outputRemoved'
        QtMocHelpers::SignalData<void(WQt::Output *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'interfaceRegistered'
        QtMocHelpers::SignalData<void(WQt::Registry::Interface)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'interfaceDeregistered'
        QtMocHelpers::SignalData<void(WQt::Registry::Interface)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ErrorType'
        QtMocHelpers::EnumData<enum ErrorType>(3, 3, QMC::EnumFlags{}).add({
            {   11, ErrorType::EmptyShm },
            {   12, ErrorType::EmptyIdle },
            {   13, ErrorType::EmptySeat },
            {   14, ErrorType::EmptyXdgWmBase },
            {   15, ErrorType::EmptyCompositor },
            {   16, ErrorType::EmptyOutputManager },
            {   17, ErrorType::EmptyTreeLandOuputManager },
        }),
        // enum 'Interface'
        QtMocHelpers::EnumData<enum Interface>(18, 18, QMC::EnumFlags{}).add({
            {   19, Interface::ShmInterface },
            {   20, Interface::IdleInterface },
            {   21, Interface::SeatInterface },
            {   22, Interface::WlrIdleInterface },
            {   23, Interface::XdgWmBaseInterface },
            {   24, Interface::CompositorInterface },
            {   25, Interface::OutputManagerInterface },
            {   26, Interface::TreeLandOutputManagerInterface },
        }),
    };
    return QtMocHelpers::metaObjectData<Registry, qt_meta_tag_ZN3WQt8RegistryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WQt::Registry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3WQt8RegistryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3WQt8RegistryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3WQt8RegistryE_t>.metaTypes,
    nullptr
} };

void WQt::Registry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Registry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->errorOccured((*reinterpret_cast<std::add_pointer_t<enum ErrorType>>(_a[1]))); break;
        case 1: _t->outputAdded((*reinterpret_cast<std::add_pointer_t<WQt::Output*>>(_a[1]))); break;
        case 2: _t->outputRemoved((*reinterpret_cast<std::add_pointer_t<WQt::Output*>>(_a[1]))); break;
        case 3: _t->interfaceRegistered((*reinterpret_cast<std::add_pointer_t<WQt::Registry::Interface>>(_a[1]))); break;
        case 4: _t->interfaceDeregistered((*reinterpret_cast<std::add_pointer_t<WQt::Registry::Interface>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(ErrorType )>(_a, &Registry::errorOccured, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(WQt::Output * )>(_a, &Registry::outputAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(WQt::Output * )>(_a, &Registry::outputRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(WQt::Registry::Interface )>(_a, &Registry::interfaceRegistered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Registry::*)(WQt::Registry::Interface )>(_a, &Registry::interfaceDeregistered, 4))
            return;
    }
}

const QMetaObject *WQt::Registry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WQt::Registry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3WQt8RegistryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WQt::Registry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void WQt::Registry::errorOccured(ErrorType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WQt::Registry::outputAdded(WQt::Output * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WQt::Registry::outputRemoved(WQt::Output * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WQt::Registry::interfaceRegistered(WQt::Registry::Interface _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WQt::Registry::interfaceDeregistered(WQt::Registry::Interface _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
