/****************************************************************************
** Meta object code from reading C++ file 'personalizationmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/personalizationmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personalizationmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20PersonalizationModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationModel::qt_create_metaobjectdata<qt_meta_tag_ZN20PersonalizationModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationModel",
        "wmChanged",
        "",
        "is3d",
        "opacityChanged",
        "opacity",
        "miniEffectChanged",
        "effect",
        "onActiveColorChanged",
        "color",
        "onCompositingAllowSwitch",
        "value",
        "windowRadiusChanged",
        "radius",
        "onSaveWindowRadiusChanged",
        "compactDisplayChanged",
        "scrollBarPolicyChanged",
        "policy",
        "titleBarHeightChanged",
        "titleBarHeight",
        "moveWindowChanged",
        "isMoveWindow",
        "windowEffectTypeChanged",
        "windowEffectType",
        "scrollBarPolicyConfigChanged",
        "config",
        "compactDisplayConfigChanged",
        "wallpaperMapChanged",
        "QVariantMap",
        "map",
        "currentSelectScreenChanged",
        "screen",
        "currentScreenSaverChanged",
        "current",
        "screensChanged",
        "screens",
        "lockScreenAtAwakeChanged",
        "linePowerScreenSaverIdleTimeChanged",
        "batteryScreenSaverIdleTimeChanged",
        "currentScreenSaverPicModeChanged",
        "wallpaperSlideShowMapChanged",
        "onBatteryChanged",
        "supportEffectsChanged",
        "miniEffect",
        "windowRadius",
        "compactDisplay",
        "scrollBarPolicy",
        "activeColor",
        "scrollBarPolicyConfig",
        "compactDisplayConfig",
        "wallpaperMap",
        "currentScreenSaver",
        "currentSelectScreen",
        "lockScreenAtAwake",
        "linePowerScreenSaverIdleTime",
        "batteryScreenSaverIdleTime",
        "currentScreenSaverPicMode",
        "wallpaperSlideShowMap",
        "onBattery",
        "supportEffects",
        "fontSizeModel",
        "FontSizeModel*",
        "standardFontModel",
        "FontModel*",
        "monoFontModel",
        "iconModel",
        "ThemeModel*",
        "cursorModel",
        "customWallpaperModel",
        "WallpaperSortModel*",
        "sysWallpaperModel",
        "solidWallpaperModel",
        "liveWallpaperModel",
        "screenSaverModel",
        "picScreenSaverModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wmChanged'
        QtMocHelpers::SignalData<void(const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(double)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Signal 'miniEffectChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'onActiveColorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'onCompositingAllowSwitch'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'windowRadiusChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'onSaveWindowRadiusChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'compactDisplayChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'scrollBarPolicyChanged'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'titleBarHeightChanged'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'moveWindowChanged'
        QtMocHelpers::SignalData<void(const bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Signal 'windowEffectTypeChanged'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'scrollBarPolicyConfigChanged'
        QtMocHelpers::SignalData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'compactDisplayConfigChanged'
        QtMocHelpers::SignalData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'wallpaperMapChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'currentSelectScreenChanged'
        QtMocHelpers::SignalData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'currentScreenSaverChanged'
        QtMocHelpers::SignalData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Signal 'screensChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 35 },
        }}),
        // Signal 'lockScreenAtAwakeChanged'
        QtMocHelpers::SignalData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'linePowerScreenSaverIdleTimeChanged'
        QtMocHelpers::SignalData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'batteryScreenSaverIdleTimeChanged'
        QtMocHelpers::SignalData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'currentScreenSaverPicModeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'wallpaperSlideShowMapChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 11 },
        }}),
        // Signal 'onBatteryChanged'
        QtMocHelpers::SignalData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'miniEffectChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'supportEffectsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'miniEffect'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'opacity'
        QtMocHelpers::PropertyData<double>(5, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'windowRadius'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'compactDisplay'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'scrollBarPolicy'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'titleBarHeight'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isMoveWindow'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'windowEffectType'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'activeColor'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'scrollBarPolicyConfig'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'compactDisplayConfig'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'wallpaperMap'
        QtMocHelpers::PropertyData<QVariantMap>(50, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'currentScreenSaver'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'currentSelectScreen'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'screens'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'lockScreenAtAwake'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'linePowerScreenSaverIdleTime'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'batteryScreenSaverIdleTime'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'currentScreenSaverPicMode'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'wallpaperSlideShowMap'
        QtMocHelpers::PropertyData<QVariantMap>(57, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 22),
        // property 'onBattery'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'supportEffects'
        QtMocHelpers::PropertyData<QStringList>(59, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'fontSizeModel'
        QtMocHelpers::PropertyData<FontSizeModel*>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'standardFontModel'
        QtMocHelpers::PropertyData<FontModel*>(62, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'monoFontModel'
        QtMocHelpers::PropertyData<FontModel*>(64, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'iconModel'
        QtMocHelpers::PropertyData<ThemeModel*>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'cursorModel'
        QtMocHelpers::PropertyData<ThemeModel*>(67, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'customWallpaperModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(68, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sysWallpaperModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(70, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'solidWallpaperModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(71, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'liveWallpaperModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(72, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'screenSaverModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(73, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'picScreenSaverModel'
        QtMocHelpers::PropertyData<WallpaperSortModel*>(74, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationModel, qt_meta_tag_ZN20PersonalizationModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PersonalizationModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PersonalizationModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20PersonalizationModelE_t>.metaTypes,
    nullptr
} };

void PersonalizationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wmChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->miniEffectChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->onActiveColorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->onCompositingAllowSwitch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->windowRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->onSaveWindowRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->compactDisplayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->scrollBarPolicyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->titleBarHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->moveWindowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->windowEffectTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->scrollBarPolicyConfigChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->compactDisplayConfigChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->wallpaperMapChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 15: _t->currentSelectScreenChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->currentScreenSaverChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->screensChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 18: _t->lockScreenAtAwakeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->linePowerScreenSaverIdleTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->batteryScreenSaverIdleTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->currentScreenSaverPicModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->wallpaperSlideShowMapChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 23: _t->onBatteryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->miniEffectChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->supportEffectsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const bool )>(_a, &PersonalizationModel::wmChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(double )>(_a, &PersonalizationModel::opacityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::miniEffectChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::onActiveColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(bool )>(_a, &PersonalizationModel::onCompositingAllowSwitch, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::windowRadiusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::onSaveWindowRadiusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(bool )>(_a, &PersonalizationModel::compactDisplayChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::scrollBarPolicyChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::titleBarHeightChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const bool )>(_a, &PersonalizationModel::moveWindowChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::windowEffectTypeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::scrollBarPolicyConfigChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::compactDisplayConfigChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QVariantMap & )>(_a, &PersonalizationModel::wallpaperMapChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::currentSelectScreenChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::currentScreenSaverChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QStringList & )>(_a, &PersonalizationModel::screensChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(bool )>(_a, &PersonalizationModel::lockScreenAtAwakeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::linePowerScreenSaverIdleTimeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(int )>(_a, &PersonalizationModel::batteryScreenSaverIdleTimeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QString & )>(_a, &PersonalizationModel::currentScreenSaverPicModeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QVariantMap & )>(_a, &PersonalizationModel::wallpaperSlideShowMapChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(bool )>(_a, &PersonalizationModel::onBatteryChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(bool )>(_a, &PersonalizationModel::miniEffectChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PersonalizationModel::*)(const QStringList & )>(_a, &PersonalizationModel::supportEffectsChanged, 25))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->miniEffect(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->getCompactDisplay(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->getScrollBarPolicy(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->getTitleBarHeight(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->getIsMoveWindow(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->windowEffectType(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->getActiveColor(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->getScrollBarPolicyConfig(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->getCompactDisplayConfig(); break;
        case 11: *reinterpret_cast<QVariantMap*>(_v) = _t->getWallpaperMap(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->getCurrentScreenSaver(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->getCurrentSelectScreen(); break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->getScreens(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->getLockScreenAtAwake(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->getLinePowerScreenSaverIdleTime(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->getBatteryScreenSaverIdleTime(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->getCurrentScreenSaverPicMode(); break;
        case 19: *reinterpret_cast<QVariantMap*>(_v) = _t->getWallpaperSlideShowMap(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->getOnBattery(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->supportEffects(); break;
        case 22: *reinterpret_cast<FontSizeModel**>(_v) = _t->m_fontSizeModel; break;
        case 23: *reinterpret_cast<FontModel**>(_v) = _t->m_standFontModel; break;
        case 24: *reinterpret_cast<FontModel**>(_v) = _t->m_monoFontModel; break;
        case 25: *reinterpret_cast<ThemeModel**>(_v) = _t->m_iconModel; break;
        case 26: *reinterpret_cast<ThemeModel**>(_v) = _t->m_mouseModel; break;
        case 27: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_customWallpaperSortModel; break;
        case 28: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_sysWallpaperSortModel; break;
        case 29: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_solidWallpaperSortModel; break;
        case 30: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_liveWallpaperSortModel; break;
        case 31: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_screenSaverSortModel; break;
        case 32: *reinterpret_cast<WallpaperSortModel**>(_v) = _t->m_picScreenSaverSortModel; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMiniEffect(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 2: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setCompactDisplay(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setScrollBarPolicy(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setTitleBarHeight(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setIsMoveWindow(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setWindowEffectType(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setScrollBarPolicyConfig(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setCompactDisplayConfig(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setWallpaperMap(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 12: _t->setCurrentScreenSaver(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setCurrentSelectScreen(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setScreens(*reinterpret_cast<QStringList*>(_v)); break;
        case 15: _t->setLockScreenAtAwake(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setLinePowerScreenSaverIdleTime(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setBatteryScreenSaverIdleTime(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setCurrentScreenSaverPicMode(*reinterpret_cast<QString*>(_v)); break;
        case 19: _t->setWallpaperSlideShowMap(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 20: _t->setOnBattery(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setSupportEffects(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PersonalizationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PersonalizationModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PersonalizationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void PersonalizationModel::wmChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PersonalizationModel::opacityChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PersonalizationModel::miniEffectChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PersonalizationModel::onActiveColorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PersonalizationModel::onCompositingAllowSwitch(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PersonalizationModel::windowRadiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PersonalizationModel::onSaveWindowRadiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PersonalizationModel::compactDisplayChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PersonalizationModel::scrollBarPolicyChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PersonalizationModel::titleBarHeightChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PersonalizationModel::moveWindowChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PersonalizationModel::windowEffectTypeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PersonalizationModel::scrollBarPolicyConfigChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PersonalizationModel::compactDisplayConfigChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void PersonalizationModel::wallpaperMapChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void PersonalizationModel::currentSelectScreenChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PersonalizationModel::currentScreenSaverChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void PersonalizationModel::screensChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void PersonalizationModel::lockScreenAtAwakeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void PersonalizationModel::linePowerScreenSaverIdleTimeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void PersonalizationModel::batteryScreenSaverIdleTimeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void PersonalizationModel::currentScreenSaverPicModeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void PersonalizationModel::wallpaperSlideShowMapChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void PersonalizationModel::onBatteryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void PersonalizationModel::miniEffectChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void PersonalizationModel::supportEffectsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}
QT_WARNING_POP
