/****************************************************************************
** Meta object code from reading C++ file 'keyboardwork.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-datetime/operation/keyboard/keyboardwork.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardwork.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::KeyboardWorker::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::KeyboardWorker",
        "KeyEvent",
        "",
        "in0",
        "in1",
        "searchChangd",
        "ShortcutInfo*",
        "info",
        "key",
        "removed",
        "id",
        "type",
        "requestSetAutoHide",
        "visible",
        "onDatasChanged",
        "QList<MetaData>",
        "datas",
        "onLettersChanged",
        "letters",
        "onResetFinished",
        "active",
        "setLang",
        "value",
        "addLang",
        "deleteLang",
        "setLayout",
        "addUserLayout",
        "delUserLayout",
        "onRequestShortcut",
        "QDBusPendingCallWatcher*",
        "watch",
        "onAdded",
        "onDisableShortcut",
        "onAddedFinished",
        "onLocalListsFinished",
        "onGetWindowWM",
        "onLayoutListsFinished",
        "onUserLayout",
        "list",
        "onUserLayoutFinished",
        "onCurrentLayout",
        "onCurrentLayoutFinished",
        "onPinyin",
        "onSearchShortcuts",
        "searchKey",
        "onSearchFinished",
        "append",
        "MetaData",
        "md",
        "onLangSelectorServiceFinished",
        "onShortcutChanged",
        "onGetShortcutFinished",
        "updateKey",
        "cleanShortcutSlef",
        "shortcut",
        "setNewCustomShortcut",
        "name",
        "command",
        "accles",
        "onConflictShortcutCleanFinished",
        "onShortcutCleanFinished",
        "onCustomConflictCleanFinished",
        "w"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'KeyEvent'
        QtMocHelpers::SignalData<void(bool, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'searchChangd'
        QtMocHelpers::SignalData<void(ShortcutInfo *, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(const QString &, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'requestSetAutoHide'
        QtMocHelpers::SignalData<void(const bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'onDatasChanged'
        QtMocHelpers::SignalData<void(QList<MetaData>)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'onLettersChanged'
        QtMocHelpers::SignalData<void(QList<QString>)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 18 },
        }}),
        // Signal 'onResetFinished'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'active'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLang'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'addLang'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'deleteLang'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setLayout'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'addUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'delUserLayout'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'onRequestShortcut'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onAdded'
        QtMocHelpers::SlotData<void(const QString &, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onDisableShortcut'
        QtMocHelpers::SlotData<void(ShortcutInfo *)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'onAddedFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onLocalListsFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onGetWindowWM'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'onLayoutListsFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onUserLayout'
        QtMocHelpers::SlotData<void(const QStringList &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 38 },
        }}),
        // Slot 'onUserLayoutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onCurrentLayout'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'onCurrentLayoutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onPinyin'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSearchShortcuts'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'onSearchFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(const MetaData &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'onLangSelectorServiceFinished'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onShortcutChanged'
        QtMocHelpers::SlotData<void(const QString &, int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'onGetShortcutFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'updateKey'
        QtMocHelpers::SlotData<void(ShortcutInfo *)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'cleanShortcutSlef'
        QtMocHelpers::SlotData<void(const QString &, const int, const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 11 }, { QMetaType::QString, 54 },
        }}),
        // Slot 'setNewCustomShortcut'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 56 }, { QMetaType::QString, 57 }, { QMetaType::QString, 58 },
        }}),
        // Slot 'onConflictShortcutCleanFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onShortcutCleanFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onCustomConflictCleanFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 62 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardWorker, qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::KeyboardWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>.metaTypes,
    nullptr
} };

void dccV25::KeyboardWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->KeyEvent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->searchChangd((*reinterpret_cast<std::add_pointer_t<ShortcutInfo*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->removed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->requestSetAutoHide((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->onDatasChanged((*reinterpret_cast<std::add_pointer_t<QList<MetaData>>>(_a[1]))); break;
        case 5: _t->onLettersChanged((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 6: _t->onResetFinished(); break;
        case 7: _t->active(); break;
        case 8: _t->setLang((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->addLang((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->deleteLang((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->addUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->delUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->onRequestShortcut((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 15: _t->onAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->onDisableShortcut((*reinterpret_cast<std::add_pointer_t<ShortcutInfo*>>(_a[1]))); break;
        case 17: _t->onAddedFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 18: _t->onLocalListsFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 19: _t->onGetWindowWM((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->onLayoutListsFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 21: _t->onUserLayout((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 22: _t->onUserLayoutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 23: _t->onCurrentLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->onCurrentLayoutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 25: _t->onPinyin(); break;
        case 26: _t->onSearchShortcuts((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->onSearchFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 28: _t->append((*reinterpret_cast<std::add_pointer_t<MetaData>>(_a[1]))); break;
        case 29: _t->onLangSelectorServiceFinished(); break;
        case 30: _t->onShortcutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 31: _t->onGetShortcutFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 32: _t->updateKey((*reinterpret_cast<std::add_pointer_t<ShortcutInfo*>>(_a[1]))); break;
        case 33: _t->cleanShortcutSlef((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 34: _t->setNewCustomShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 35: _t->onConflictShortcutCleanFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 36: _t->onShortcutCleanFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 37: _t->onCustomConflictCleanFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(bool , const QString & )>(_a, &KeyboardWorker::KeyEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(ShortcutInfo * , const QString & )>(_a, &KeyboardWorker::searchChangd, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(const QString & , int )>(_a, &KeyboardWorker::removed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(const bool )>(_a, &KeyboardWorker::requestSetAutoHide, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(QList<MetaData> )>(_a, &KeyboardWorker::onDatasChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)(QList<QString> )>(_a, &KeyboardWorker::onLettersChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardWorker::*)()>(_a, &KeyboardWorker::onResetFinished, 6))
            return;
    }
}

const QMetaObject *dccV25::KeyboardWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::KeyboardWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2514KeyboardWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::KeyboardWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void dccV25::KeyboardWorker::KeyEvent(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dccV25::KeyboardWorker::searchChangd(ShortcutInfo * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void dccV25::KeyboardWorker::removed(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dccV25::KeyboardWorker::requestSetAutoHide(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::KeyboardWorker::onDatasChanged(QList<MetaData> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::KeyboardWorker::onLettersChanged(QList<QString> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::KeyboardWorker::onResetFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
