/****************************************************************************
** Meta object code from reading C++ file 'monitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/private/monitor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV257MonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::Monitor::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV257MonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::Monitor",
        "geometryChanged",
        "",
        "xChanged",
        "x",
        "yChanged",
        "y",
        "wChanged",
        "w",
        "hChanged",
        "h",
        "scaleChanged",
        "scale",
        "rotateChanged",
        "rotate",
        "brightnessChanged",
        "brightness",
        "currentModeChanged",
        "Resolution",
        "resolution",
        "modelListChanged",
        "QList<Resolution>",
        "enableChanged",
        "enable",
        "bestModeChanged",
        "availableFillModesChanged",
        "fillModeList",
        "currentRotateModeChanged",
        "currentFillModeChanged",
        "currentFillMode",
        "wallpaperChanged",
        "setX",
        "setY",
        "setW",
        "setH",
        "setMmWidth",
        "mmWidth",
        "setMmHeight",
        "mmHeight",
        "setScale",
        "setPrimary",
        "primaryName",
        "setRotate",
        "setBrightness",
        "setName",
        "name",
        "setManufacturer",
        "manufacturer",
        "setModel",
        "model",
        "setCanBrightness",
        "canBrightness",
        "setPath",
        "path",
        "setRotateList",
        "QList<quint16>",
        "rotateList",
        "setCurrentMode",
        "setModeList",
        "ResolutionList",
        "modeList",
        "setMonitorEnable",
        "setBestMode",
        "mode",
        "setCurrentRotateMode",
        "setAvailableFillModes",
        "setCurrentFillMode",
        "getResolutionById",
        "std::optional<Resolution>",
        "id",
        "setWallpaper",
        "wallpaper"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void(const int) const>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void(const int) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'wChanged'
        QtMocHelpers::SignalData<void(const int) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'hChanged'
        QtMocHelpers::SignalData<void(const int) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void(const double) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 12 },
        }}),
        // Signal 'rotateChanged'
        QtMocHelpers::SignalData<void(const quint16) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 14 },
        }}),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void(const double) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Signal 'currentModeChanged'
        QtMocHelpers::SignalData<void(const Resolution &) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'modelListChanged'
        QtMocHelpers::SignalData<void(const QList<Resolution> &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 19 },
        }}),
        // Signal 'enableChanged'
        QtMocHelpers::SignalData<void(bool) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'bestModeChanged'
        QtMocHelpers::SignalData<void() const>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableFillModesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Signal 'currentRotateModeChanged'
        QtMocHelpers::SignalData<void() const>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentFillModeChanged'
        QtMocHelpers::SignalData<void(QString) const>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void() const>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setX'
        QtMocHelpers::SlotData<void(const int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setY'
        QtMocHelpers::SlotData<void(const int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setW'
        QtMocHelpers::SlotData<void(const int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setH'
        QtMocHelpers::SlotData<void(const int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'setMmWidth'
        QtMocHelpers::SlotData<void(const uint)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 36 },
        }}),
        // Slot 'setMmHeight'
        QtMocHelpers::SlotData<void(const uint)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 38 },
        }}),
        // Slot 'setScale'
        QtMocHelpers::SlotData<void(const double)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 12 },
        }}),
        // Slot 'setPrimary'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'setRotate'
        QtMocHelpers::SlotData<void(const quint16)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UShort, 14 },
        }}),
        // Slot 'setBrightness'
        QtMocHelpers::SlotData<void(const double)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'setManufacturer'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'setCanBrightness'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setPath'
        QtMocHelpers::SlotData<void(const QString &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'setRotateList'
        QtMocHelpers::SlotData<void(const QList<quint16> &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'setCurrentMode'
        QtMocHelpers::SlotData<void(const Resolution &)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setModeList'
        QtMocHelpers::SlotData<void(const ResolutionList &)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setMonitorEnable'
        QtMocHelpers::SlotData<void(bool)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setBestMode'
        QtMocHelpers::SlotData<void(const Resolution &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 63 },
        }}),
        // Slot 'setCurrentRotateMode'
        QtMocHelpers::SlotData<void(const unsigned char)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UChar, 63 },
        }}),
        // Slot 'setAvailableFillModes'
        QtMocHelpers::SlotData<void(const QStringList &)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'setCurrentFillMode'
        QtMocHelpers::SlotData<void(const QString)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'getResolutionById'
        QtMocHelpers::SlotData<std::optional<Resolution>(quint32)>(67, 2, QMC::AccessPrivate, 0x80000000 | 68, {{
            { QMetaType::UInt, 69 },
        }}),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QString &)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 71 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Monitor, qt_meta_tag_ZN6dccV257MonitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::Monitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV257MonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV257MonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV257MonitorE_t>.metaTypes,
    nullptr
} };

void dccV25::Monitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Monitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->geometryChanged(); break;
        case 1: _t->xChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->yChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->wChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->hChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->scaleChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->rotateChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 7: _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->currentModeChanged((*reinterpret_cast<std::add_pointer_t<Resolution>>(_a[1]))); break;
        case 9: _t->modelListChanged((*reinterpret_cast<std::add_pointer_t<QList<Resolution>>>(_a[1]))); break;
        case 10: _t->enableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->bestModeChanged(); break;
        case 12: _t->availableFillModesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->currentRotateModeChanged(); break;
        case 14: _t->currentFillModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->wallpaperChanged(); break;
        case 16: _t->setX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setY((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setW((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setH((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setMmWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 21: _t->setMmHeight((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 22: _t->setScale((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: _t->setPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setRotate((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 25: _t->setBrightness((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 26: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setManufacturer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setCanBrightness((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setRotateList((*reinterpret_cast<std::add_pointer_t<QList<quint16>>>(_a[1]))); break;
        case 32: _t->setCurrentMode((*reinterpret_cast<std::add_pointer_t<Resolution>>(_a[1]))); break;
        case 33: _t->setModeList((*reinterpret_cast<std::add_pointer_t<ResolutionList>>(_a[1]))); break;
        case 34: _t->setMonitorEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setBestMode((*reinterpret_cast<std::add_pointer_t<Resolution>>(_a[1]))); break;
        case 36: _t->setCurrentRotateMode((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1]))); break;
        case 37: _t->setAvailableFillModes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 38: _t->setCurrentFillMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: { std::optional<Resolution> _r = _t->getResolutionById((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])));
            if (_a[0]) *reinterpret_cast<std::optional<Resolution>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Resolution >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Resolution> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<quint16> >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Resolution >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Resolution >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)() const>(_a, &Monitor::geometryChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const int ) const>(_a, &Monitor::xChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const int ) const>(_a, &Monitor::yChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const int ) const>(_a, &Monitor::wChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const int ) const>(_a, &Monitor::hChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const double ) const>(_a, &Monitor::scaleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const quint16 ) const>(_a, &Monitor::rotateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const double ) const>(_a, &Monitor::brightnessChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Resolution & ) const>(_a, &Monitor::currentModeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const QList<Resolution> & ) const>(_a, &Monitor::modelListChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(bool ) const>(_a, &Monitor::enableChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)() const>(_a, &Monitor::bestModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const QStringList & )>(_a, &Monitor::availableFillModesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)() const>(_a, &Monitor::currentRotateModeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(QString ) const>(_a, &Monitor::currentFillModeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)() const>(_a, &Monitor::wallpaperChanged, 15))
            return;
    }
}

const QMetaObject *dccV25::Monitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::Monitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV257MonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::Monitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void dccV25::Monitor::geometryChanged()const
{
    QMetaObject::activate(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dccV25::Monitor::xChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::Monitor::yChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::Monitor::wChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::Monitor::hChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::Monitor::scaleChanged(const double _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::Monitor::rotateChanged(const quint16 _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dccV25::Monitor::brightnessChanged(const double _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dccV25::Monitor::currentModeChanged(const Resolution & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dccV25::Monitor::modelListChanged(const QList<Resolution> & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::Monitor::enableChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dccV25::Monitor::bestModeChanged()const
{
    QMetaObject::activate(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dccV25::Monitor::availableFillModesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dccV25::Monitor::currentRotateModeChanged()const
{
    QMetaObject::activate(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dccV25::Monitor::currentFillModeChanged(QString _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::Monitor::wallpaperChanged()const
{
    QMetaObject::activate(const_cast< dccV25::Monitor *>(this), &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
