/****************************************************************************
** Meta object code from reading C++ file 'displaymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-display/operation/private/displaymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displaymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2512DisplayModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::DisplayModel::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2512DisplayModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::DisplayModel",
        "screenHeightChanged",
        "",
        "h",
        "screenWidthChanged",
        "w",
        "displayModeChanged",
        "mode",
        "uiScaleChanged",
        "scale",
        "minimumBrightnessScaleChanged",
        "primaryScreenChanged",
        "primary",
        "monitorListChanged",
        "machinesListChanged",
        "nightModeChanged",
        "nightmode",
        "redshiftVaildChanged",
        "isvalid",
        "autoLightAdjustSettingChanged",
        "setting",
        "autoLightAdjustVaildChanged",
        "touchscreenListChanged",
        "touchscreenMapChanged",
        "maxBacklightBrightnessChanged",
        "value",
        "adjustCCTmodeChanged",
        "colorTemperatureEnabledChanged",
        "enabled",
        "colorTemperatureChanged",
        "resolutionRefreshEnableChanged",
        "enable",
        "brightnessEnableChanged",
        "deviceSharingSwitchChanged",
        "sharedClipboardChanged",
        "on",
        "sharedDevicesChanged",
        "filesStoragePathChanged",
        "path",
        "customColorTempTimePeriodChanged",
        "timePeriod",
        "setScreenHeight",
        "setScreenWidth",
        "setDisplayMode",
        "setUIScale",
        "setMinimumBrightnessScale",
        "setPrimary",
        "setRedshiftIsValid",
        "redshiftIsValid",
        "monitorAdded",
        "Monitor*",
        "mon",
        "monitorRemoved",
        "setAutoLightAdjustIsValid",
        "setmaxBacklightBrightness"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'screenHeightChanged'
        QtMocHelpers::SignalData<void(const int) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'screenWidthChanged'
        QtMocHelpers::SignalData<void(const int) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'displayModeChanged'
        QtMocHelpers::SignalData<void(const int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'uiScaleChanged'
        QtMocHelpers::SignalData<void(const double) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Signal 'minimumBrightnessScaleChanged'
        QtMocHelpers::SignalData<void(const double) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Signal 'primaryScreenChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'monitorListChanged'
        QtMocHelpers::SignalData<void() const>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'machinesListChanged'
        QtMocHelpers::SignalData<void() const>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nightModeChanged'
        QtMocHelpers::SignalData<void(const bool) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'redshiftVaildChanged'
        QtMocHelpers::SignalData<void(const bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'autoLightAdjustSettingChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'autoLightAdjustVaildChanged'
        QtMocHelpers::SignalData<void(bool) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'touchscreenListChanged'
        QtMocHelpers::SignalData<void() const>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'touchscreenMapChanged'
        QtMocHelpers::SignalData<void() const>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxBacklightBrightnessChanged'
        QtMocHelpers::SignalData<void(uint)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
        // Signal 'adjustCCTmodeChanged'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'colorTemperatureEnabledChanged'
        QtMocHelpers::SignalData<void(const bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'colorTemperatureChanged'
        QtMocHelpers::SignalData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Signal 'resolutionRefreshEnableChanged'
        QtMocHelpers::SignalData<void(const bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'brightnessEnableChanged'
        QtMocHelpers::SignalData<void(const bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'deviceSharingSwitchChanged'
        QtMocHelpers::SignalData<void(const bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'sharedClipboardChanged'
        QtMocHelpers::SignalData<void(bool) const>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Signal 'sharedDevicesChanged'
        QtMocHelpers::SignalData<void(bool) const>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Signal 'filesStoragePathChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Signal 'customColorTempTimePeriodChanged'
        QtMocHelpers::SignalData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'setScreenHeight'
        QtMocHelpers::SlotData<void(const int)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setScreenWidth'
        QtMocHelpers::SlotData<void(const int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setDisplayMode'
        QtMocHelpers::SlotData<void(const int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setUIScale'
        QtMocHelpers::SlotData<void(const double)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Slot 'setMinimumBrightnessScale'
        QtMocHelpers::SlotData<void(const double)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Slot 'setPrimary'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setRedshiftIsValid'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Slot 'monitorAdded'
        QtMocHelpers::SlotData<void(Monitor *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'monitorRemoved'
        QtMocHelpers::SlotData<void(Monitor *)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'setAutoLightAdjustIsValid'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setmaxBacklightBrightness'
        QtMocHelpers::SlotData<void(const uint)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisplayModel, qt_meta_tag_ZN6dccV2512DisplayModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::DisplayModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2512DisplayModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2512DisplayModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2512DisplayModelE_t>.metaTypes,
    nullptr
} };

void dccV25::DisplayModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->screenHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->screenWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->displayModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->uiScaleChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->minimumBrightnessScaleChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->primaryScreenChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->monitorListChanged(); break;
        case 7: _t->machinesListChanged(); break;
        case 8: _t->nightModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->redshiftVaildChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->autoLightAdjustSettingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->autoLightAdjustVaildChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->touchscreenListChanged(); break;
        case 13: _t->touchscreenMapChanged(); break;
        case 14: _t->maxBacklightBrightnessChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 15: _t->adjustCCTmodeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->colorTemperatureEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->colorTemperatureChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->resolutionRefreshEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->brightnessEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->deviceSharingSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->sharedClipboardChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->sharedDevicesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->filesStoragePathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->customColorTempTimePeriodChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setScreenHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setScreenWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setDisplayMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setUIScale((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 29: _t->setMinimumBrightnessScale((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 30: _t->setPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setRedshiftIsValid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->monitorAdded((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1]))); break;
        case 33: _t->monitorRemoved((*reinterpret_cast<std::add_pointer_t<Monitor*>>(_a[1]))); break;
        case 34: _t->setAutoLightAdjustIsValid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setmaxBacklightBrightness((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Monitor* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const int ) const>(_a, &DisplayModel::screenHeightChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const int ) const>(_a, &DisplayModel::screenWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const int ) const>(_a, &DisplayModel::displayModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const double ) const>(_a, &DisplayModel::uiScaleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const double ) const>(_a, &DisplayModel::minimumBrightnessScaleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const QString & ) const>(_a, &DisplayModel::primaryScreenChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)() const>(_a, &DisplayModel::monitorListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)() const>(_a, &DisplayModel::machinesListChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool ) const>(_a, &DisplayModel::nightModeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool ) const>(_a, &DisplayModel::redshiftVaildChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(bool ) const>(_a, &DisplayModel::autoLightAdjustSettingChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(bool ) const>(_a, &DisplayModel::autoLightAdjustVaildChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)() const>(_a, &DisplayModel::touchscreenListChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)() const>(_a, &DisplayModel::touchscreenMapChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(uint )>(_a, &DisplayModel::maxBacklightBrightnessChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(int )>(_a, &DisplayModel::adjustCCTmodeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool )>(_a, &DisplayModel::colorTemperatureEnabledChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(int )>(_a, &DisplayModel::colorTemperatureChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool )>(_a, &DisplayModel::resolutionRefreshEnableChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool )>(_a, &DisplayModel::brightnessEnableChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const bool )>(_a, &DisplayModel::deviceSharingSwitchChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(bool ) const>(_a, &DisplayModel::sharedClipboardChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(bool ) const>(_a, &DisplayModel::sharedDevicesChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const QString & ) const>(_a, &DisplayModel::filesStoragePathChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)(const QString & )>(_a, &DisplayModel::customColorTempTimePeriodChanged, 24))
            return;
    }
}

const QMetaObject *dccV25::DisplayModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::DisplayModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2512DisplayModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::DisplayModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void dccV25::DisplayModel::screenHeightChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::DisplayModel::screenWidthChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::DisplayModel::displayModeChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::DisplayModel::uiScaleChanged(const double _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::DisplayModel::minimumBrightnessScaleChanged(const double _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::DisplayModel::primaryScreenChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::DisplayModel::monitorListChanged()const
{
    QMetaObject::activate(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dccV25::DisplayModel::machinesListChanged()const
{
    QMetaObject::activate(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dccV25::DisplayModel::nightModeChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dccV25::DisplayModel::redshiftVaildChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::DisplayModel::autoLightAdjustSettingChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dccV25::DisplayModel::autoLightAdjustVaildChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dccV25::DisplayModel::touchscreenListChanged()const
{
    QMetaObject::activate(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void dccV25::DisplayModel::touchscreenMapChanged()const
{
    QMetaObject::activate(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dccV25::DisplayModel::maxBacklightBrightnessChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::DisplayModel::adjustCCTmodeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dccV25::DisplayModel::colorTemperatureEnabledChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dccV25::DisplayModel::colorTemperatureChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dccV25::DisplayModel::resolutionRefreshEnableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void dccV25::DisplayModel::brightnessEnableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void dccV25::DisplayModel::deviceSharingSwitchChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void dccV25::DisplayModel::sharedClipboardChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void dccV25::DisplayModel::sharedDevicesChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void dccV25::DisplayModel::filesStoragePathChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::DisplayModel *>(this), &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void dccV25::DisplayModel::customColorTempTimePeriodChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}
QT_WARNING_POP
