/****************************************************************************
** Meta object code from reading C++ file 'deepinidworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-deepinid/operation/deepinidworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'deepinidworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12DeepinWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto DeepinWorker::qt_create_metaobjectdata<qt_meta_tag_ZN12DeepinWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeepinWorker",
        "onSyncSwitcherChange",
        "",
        "key",
        "enable",
        "onLastSyncTimeChanged",
        "lastSyncTime",
        "licenseStateChangeSlot",
        "onUtcloudSwitcherChange",
        "QVariantList",
        "args",
        "onUtcloudLoginStatusChange",
        "onBindSuccess",
        "loginUser",
        "logoutUser",
        "openWeb",
        "setFullName",
        "name",
        "setAutoSync",
        "autoSync",
        "setSyncSwitcher",
        "keyList",
        "setUtcloudSwitcher",
        "checkPasswdEmpty",
        "checkPassword",
        "QVariantMap",
        "passwd",
        "registerPasswd",
        "clearData",
        "openForgetPasswd",
        "unBindPlatform",
        "bindAccount"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onSyncSwitcherChange'
        QtMocHelpers::SlotData<void(const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'onLastSyncTimeChanged'
        QtMocHelpers::SlotData<void(qlonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 },
        }}),
        // Slot 'licenseStateChangeSlot'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUtcloudSwitcherChange'
        QtMocHelpers::SlotData<void(const QVariantList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onUtcloudLoginStatusChange'
        QtMocHelpers::SlotData<void(const QVariantList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onBindSuccess'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'loginUser'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'logoutUser'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openWeb'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setFullName'
        QtMocHelpers::MethodData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'setAutoSync'
        QtMocHelpers::MethodData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Method 'setSyncSwitcher'
        QtMocHelpers::MethodData<void(const QStringList &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 21 }, { QMetaType::Bool, 4 },
        }}),
        // Method 'setUtcloudSwitcher'
        QtMocHelpers::MethodData<void(const QString &, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Method 'checkPasswdEmpty'
        QtMocHelpers::MethodData<bool()>(23, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'checkPassword'
        QtMocHelpers::MethodData<QVariantMap(const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'registerPasswd'
        QtMocHelpers::MethodData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'clearData'
        QtMocHelpers::MethodData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openForgetPasswd'
        QtMocHelpers::MethodData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'unBindPlatform'
        QtMocHelpers::MethodData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'bindAccount'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeepinWorker, qt_meta_tag_ZN12DeepinWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeepinWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DeepinWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DeepinWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12DeepinWorkerE_t>.metaTypes,
    nullptr
} };

void DeepinWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeepinWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onSyncSwitcherChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->onLastSyncTimeChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 2: _t->licenseStateChangeSlot(); break;
        case 3: _t->onUtcloudSwitcherChange((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 4: _t->onUtcloudLoginStatusChange((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 5: _t->onBindSuccess(); break;
        case 6: _t->loginUser(); break;
        case 7: _t->logoutUser(); break;
        case 8: _t->openWeb(); break;
        case 9: _t->setFullName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setAutoSync((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setSyncSwitcher((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->setUtcloudSwitcher((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: { bool _r = _t->checkPasswdEmpty();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QVariantMap _r = _t->checkPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->registerPasswd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->clearData(); break;
        case 17: _t->openForgetPasswd(); break;
        case 18: _t->unBindPlatform(); break;
        case 19: _t->bindAccount(); break;
        default: ;
        }
    }
}

const QMetaObject *DeepinWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeepinWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DeepinWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeepinWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
