/****************************************************************************
** Meta object code from reading C++ file 'powermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-power/operation/powermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerModel::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerModel",
        "sleepLockChanged",
        "",
        "sleepLock",
        "canSuspendChanged",
        "canSuspend",
        "screenBlackLockChanged",
        "screenBlackLock",
        "lidPresentChanged",
        "lidPresent",
        "sleepOnLidOnPowerCloseChanged",
        "sleepOnLidClose",
        "sleepOnLidOnBatteryCloseChanged",
        "screenBlackDelayChangedOnPower",
        "screenBlackDelay",
        "sleepDelayChangedOnPower",
        "sleepDelay",
        "screenBlackDelayChangedOnBattery",
        "sleepDelayChangedOnBattery",
        "canHibernateChanged",
        "canHibernate",
        "hibernateChanged",
        "hibernate",
        "shutdownChanged",
        "shutdown",
        "autoPowerSavingModeChanged",
        "autoPowerSaveMode",
        "powerSaveModeChanged",
        "powerSaveMode",
        "haveBettaryChanged",
        "haveBettary",
        "batteryLockScreenDelayChanged",
        "batteryLockScreenTime",
        "powerLockScreenDelayChanged",
        "powerLockScreenTime",
        "powerSavingModeAutoWhenQuantifyLowChanged",
        "state",
        "powerSavingModeAutoChanged",
        "powerSavingModeLowerBrightnessThresholdChanged",
        "level",
        "powerSavingModeAutoBatteryPercentageChanged",
        "linePowerPressPowerBtnActionChanged",
        "reply",
        "linePowerLidClosedActionChanged",
        "batteryPressPowerBtnActionChanged",
        "batteryLidClosedActionChanged",
        "lowPowerNotifyEnableChanged",
        "lowPowerNotifyThresholdChanged",
        "value",
        "lowPowerAutoSleepThresholdChanged",
        "suspendChanged",
        "suspendState",
        "powerPlanChanged",
        "highPerformaceSupportChanged",
        "noPasswdLoginChanged",
        "batteryCapacityChanged",
        "showBatteryTimeToFullChanged",
        "scheduledShutdownStateChanged",
        "shutdownTimeChanged",
        "time",
        "shutdownRepetitionChanged",
        "repetition",
        "weekBeginsChanged",
        "customShutdownWeekDaysChanged",
        "QVariantList",
        "isVirtualEnvironmentChanged",
        "isVirtualEnvironment",
        "batteryLockDelayModelChanged",
        "batteryScreenBlackDelayModelChanged",
        "batterySleepDelayModelChanged",
        "linePowerLockDelayModelChanged",
        "linePowerScreenBlackDelayModelChanged",
        "linePowerSleepDelayModelChanged",
        "lowPowerActionChanged",
        "action",
        "enableScheduledShutdownChanged",
        "refreshShutdownRepetition",
        "sleepOnLidOnPowerClose",
        "sleepOnLidOnBatteryClose",
        "screenBlackDelayOnPower",
        "sleepDelayOnPower",
        "screenBlackDelayOnBattery",
        "sleepDelayOnBattery",
        "batteryLockScreenDelay",
        "powerLockScreenDelay",
        "powerSavingModeAutoWhenQuantifyLow",
        "powerSavingModeAuto",
        "powerSavingModeLowerBrightnessThreshold",
        "powerSavingModeAutoBatteryPercentage",
        "linePowerPressPowerBtnAction",
        "linePowerLidClosedAction",
        "batteryPressPowerBtnAction",
        "batteryLidClosedAction",
        "lowPowerNotifyEnable",
        "lowPowerNotifyThreshold",
        "lowPowerAutoSleepThreshold",
        "isSuspend",
        "isHibernate",
        "isShutdown",
        "powerPlan",
        "isHighPerformanceSupported",
        "isBalancePerformanceSupported",
        "isNoPasswdLogin",
        "batteryCapacity",
        "showBatteryTimeToFull",
        "scheduledShutdownState",
        "shutdownTime",
        "shutdownRepetition",
        "weekBegins",
        "lowPowerAction",
        "customShutdownWeekDays",
        "batteryLockDelayModel",
        "batteryScreenBlackDelayModel",
        "batterySleepDelayModel",
        "linePowerLockDelayModel",
        "linePowerScreenBlackDelayModel",
        "linePowerSleepDelayModel",
        "enableScheduledShutdown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sleepLockChanged'
        QtMocHelpers::SignalData<void(const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'canSuspendChanged'
        QtMocHelpers::SignalData<void(const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'screenBlackLockChanged'
        QtMocHelpers::SignalData<void(const bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'lidPresentChanged'
        QtMocHelpers::SignalData<void(const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'sleepOnLidOnPowerCloseChanged'
        QtMocHelpers::SignalData<void(const bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'sleepOnLidOnBatteryCloseChanged'
        QtMocHelpers::SignalData<void(const bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'screenBlackDelayChangedOnPower'
        QtMocHelpers::SignalData<void(const int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'sleepDelayChangedOnPower'
        QtMocHelpers::SignalData<void(const int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'screenBlackDelayChangedOnBattery'
        QtMocHelpers::SignalData<void(const int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'sleepDelayChangedOnBattery'
        QtMocHelpers::SignalData<void(const int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'canHibernateChanged'
        QtMocHelpers::SignalData<void(const bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'hibernateChanged'
        QtMocHelpers::SignalData<void(const bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'shutdownChanged'
        QtMocHelpers::SignalData<void(const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'autoPowerSavingModeChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'powerSaveModeChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'haveBettaryChanged'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'batteryLockScreenDelayChanged'
        QtMocHelpers::SignalData<void(const int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Signal 'powerLockScreenDelayChanged'
        QtMocHelpers::SignalData<void(const int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'powerSavingModeAutoWhenQuantifyLowChanged'
        QtMocHelpers::SignalData<void(const bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Signal 'powerSavingModeAutoChanged'
        QtMocHelpers::SignalData<void(const bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Signal 'powerSavingModeLowerBrightnessThresholdChanged'
        QtMocHelpers::SignalData<void(const uint)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 39 },
        }}),
        // Signal 'powerSavingModeAutoBatteryPercentageChanged'
        QtMocHelpers::SignalData<void(const uint)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 39 },
        }}),
        // Signal 'linePowerPressPowerBtnActionChanged'
        QtMocHelpers::SignalData<void(const int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'linePowerLidClosedActionChanged'
        QtMocHelpers::SignalData<void(const int)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'batteryPressPowerBtnActionChanged'
        QtMocHelpers::SignalData<void(const int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'batteryLidClosedActionChanged'
        QtMocHelpers::SignalData<void(const int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'lowPowerNotifyEnableChanged'
        QtMocHelpers::SignalData<void(const bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Signal 'lowPowerNotifyThresholdChanged'
        QtMocHelpers::SignalData<void(const int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Signal 'lowPowerAutoSleepThresholdChanged'
        QtMocHelpers::SignalData<void(const int)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Signal 'suspendChanged'
        QtMocHelpers::SignalData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Signal 'powerPlanChanged'
        QtMocHelpers::SignalData<void(const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Signal 'highPerformaceSupportChanged'
        QtMocHelpers::SignalData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Signal 'noPasswdLoginChanged'
        QtMocHelpers::SignalData<void(bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Signal 'batteryCapacityChanged'
        QtMocHelpers::SignalData<void(double)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 48 },
        }}),
        // Signal 'showBatteryTimeToFullChanged'
        QtMocHelpers::SignalData<void(bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Signal 'scheduledShutdownStateChanged'
        QtMocHelpers::SignalData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Signal 'shutdownTimeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 59 },
        }}),
        // Signal 'shutdownRepetitionChanged'
        QtMocHelpers::SignalData<void(int)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Signal 'weekBeginsChanged'
        QtMocHelpers::SignalData<void(int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Signal 'customShutdownWeekDaysChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'isVirtualEnvironmentChanged'
        QtMocHelpers::SignalData<void(bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Signal 'batteryLockDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'batteryScreenBlackDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'batterySleepDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'linePowerLockDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'linePowerScreenBlackDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'linePowerSleepDelayModelChanged'
        QtMocHelpers::SignalData<void(const QVariantList &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 48 },
        }}),
        // Signal 'lowPowerActionChanged'
        QtMocHelpers::SignalData<void(int)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 74 },
        }}),
        // Signal 'enableScheduledShutdownChanged'
        QtMocHelpers::SignalData<void(const QString &)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Method 'refreshShutdownRepetition'
        QtMocHelpers::MethodData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lidPresent'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'sleepOnLidOnPowerClose'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'sleepOnLidOnBatteryClose'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'screenBlackLock'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sleepLock'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'canSuspend'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'canHibernate'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'screenBlackDelayOnPower'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'sleepDelayOnPower'
        QtMocHelpers::PropertyData<int>(80, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'screenBlackDelayOnBattery'
        QtMocHelpers::PropertyData<int>(81, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'sleepDelayOnBattery'
        QtMocHelpers::PropertyData<int>(82, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'autoPowerSaveMode'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'powerSaveMode'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'haveBettary'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'batteryLockScreenDelay'
        QtMocHelpers::PropertyData<int>(83, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'powerLockScreenDelay'
        QtMocHelpers::PropertyData<int>(84, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'powerSavingModeAutoWhenQuantifyLow'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'powerSavingModeAuto'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'powerSavingModeLowerBrightnessThreshold'
        QtMocHelpers::PropertyData<uint>(87, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'powerSavingModeAutoBatteryPercentage'
        QtMocHelpers::PropertyData<uint>(88, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'linePowerPressPowerBtnAction'
        QtMocHelpers::PropertyData<int>(89, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'linePowerLidClosedAction'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'batteryPressPowerBtnAction'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'batteryLidClosedAction'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'lowPowerNotifyEnable'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'lowPowerNotifyThreshold'
        QtMocHelpers::PropertyData<int>(94, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'lowPowerAutoSleepThreshold'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isSuspend'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 29),
        // property 'isHibernate'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 11),
        // property 'isShutdown'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 12),
        // property 'powerPlan'
        QtMocHelpers::PropertyData<QString>(99, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isHighPerformanceSupported'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 31),
        // property 'isBalancePerformanceSupported'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 31),
        // property 'isNoPasswdLogin'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 32),
        // property 'batteryCapacity'
        QtMocHelpers::PropertyData<int>(103, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'showBatteryTimeToFull'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'scheduledShutdownState'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'shutdownTime'
        QtMocHelpers::PropertyData<QString>(106, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'shutdownRepetition'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'weekBegins'
        QtMocHelpers::PropertyData<int>(108, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'lowPowerAction'
        QtMocHelpers::PropertyData<int>(109, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'customShutdownWeekDays'
        QtMocHelpers::PropertyData<QVariantList>(110, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 39),
        // property 'isVirtualEnvironment'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'batteryLockDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(111, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 41),
        // property 'batteryScreenBlackDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(112, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 42),
        // property 'batterySleepDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(113, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 43),
        // property 'linePowerLockDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(114, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 44),
        // property 'linePowerScreenBlackDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(115, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 45),
        // property 'linePowerSleepDelayModel'
        QtMocHelpers::PropertyData<QVariantList>(116, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 46),
        // property 'enableScheduledShutdown'
        QtMocHelpers::PropertyData<QString>(117, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerModel, qt_meta_tag_ZN10PowerModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerModelE_t>.metaTypes,
    nullptr
} };

void PowerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sleepLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->canSuspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->screenBlackLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->lidPresentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->sleepOnLidOnPowerCloseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->sleepOnLidOnBatteryCloseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->screenBlackDelayChangedOnPower((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->sleepDelayChangedOnPower((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->screenBlackDelayChangedOnBattery((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->sleepDelayChangedOnBattery((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->canHibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->hibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->shutdownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->autoPowerSavingModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->powerSaveModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->haveBettaryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->batteryLockScreenDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->powerLockScreenDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->powerSavingModeAutoWhenQuantifyLowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->powerSavingModeAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->powerSavingModeLowerBrightnessThresholdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 21: _t->powerSavingModeAutoBatteryPercentageChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 22: _t->linePowerPressPowerBtnActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->linePowerLidClosedActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->batteryPressPowerBtnActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->batteryLidClosedActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->lowPowerNotifyEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->lowPowerNotifyThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->lowPowerAutoSleepThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->suspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->powerPlanChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->highPerformaceSupportChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->noPasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->batteryCapacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 34: _t->showBatteryTimeToFullChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->scheduledShutdownStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->shutdownTimeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->shutdownRepetitionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->weekBeginsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->customShutdownWeekDaysChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 40: _t->isVirtualEnvironmentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->batteryLockDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 42: _t->batteryScreenBlackDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 43: _t->batterySleepDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 44: _t->linePowerLockDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 45: _t->linePowerScreenBlackDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 46: _t->linePowerSleepDelayModelChanged((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 47: _t->lowPowerActionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->enableScheduledShutdownChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->refreshShutdownRepetition(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::sleepLockChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::canSuspendChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::screenBlackLockChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::lidPresentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::sleepOnLidOnPowerCloseChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::sleepOnLidOnBatteryCloseChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::screenBlackDelayChangedOnPower, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::sleepDelayChangedOnPower, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::screenBlackDelayChangedOnBattery, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::sleepDelayChangedOnBattery, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::canHibernateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::hibernateChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::shutdownChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::autoPowerSavingModeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::powerSaveModeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::haveBettaryChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::batteryLockScreenDelayChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::powerLockScreenDelayChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::powerSavingModeAutoWhenQuantifyLowChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::powerSavingModeAutoChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const uint )>(_a, &PowerModel::powerSavingModeLowerBrightnessThresholdChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const uint )>(_a, &PowerModel::powerSavingModeAutoBatteryPercentageChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::linePowerPressPowerBtnActionChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::linePowerLidClosedActionChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::batteryPressPowerBtnActionChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::batteryLidClosedActionChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const bool )>(_a, &PowerModel::lowPowerNotifyEnableChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::lowPowerNotifyThresholdChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const int )>(_a, &PowerModel::lowPowerAutoSleepThresholdChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::suspendChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QString & )>(_a, &PowerModel::powerPlanChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::highPerformaceSupportChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::noPasswdLoginChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(double )>(_a, &PowerModel::batteryCapacityChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::showBatteryTimeToFullChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::scheduledShutdownStateChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QString & )>(_a, &PowerModel::shutdownTimeChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(int )>(_a, &PowerModel::shutdownRepetitionChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(int )>(_a, &PowerModel::weekBeginsChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::customShutdownWeekDaysChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(bool )>(_a, &PowerModel::isVirtualEnvironmentChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::batteryLockDelayModelChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::batteryScreenBlackDelayModelChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::batterySleepDelayModelChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::linePowerLockDelayModelChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::linePowerScreenBlackDelayModelChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QVariantList & )>(_a, &PowerModel::linePowerSleepDelayModelChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(int )>(_a, &PowerModel::lowPowerActionChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerModel::*)(const QString & )>(_a, &PowerModel::enableScheduledShutdownChanged, 48))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->lidPresent(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->sleepOnLidOnPowerClose(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->sleepOnLidOnBatteryClose(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->screenBlackLock(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->sleepLock(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canSuspend(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canHibernate(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->screenBlackDelayOnPower(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->sleepDelayOnPower(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->screenBlackDelayOnBattery(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->sleepDelayOnBattery(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->autoPowerSaveMode(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->powerSaveMode(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->haveBettary(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->getBatteryLockScreenDelay(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->getPowerLockScreenDelay(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAutoWhenQuantifyLow(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->powerSavingModeAuto(); break;
        case 18: *reinterpret_cast<uint*>(_v) = _t->powerSavingModeLowerBrightnessThreshold(); break;
        case 19: *reinterpret_cast<uint*>(_v) = _t->powerSavingModeAutoBatteryPercentage(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->linePowerPressPowerBtnAction(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->linePowerLidClosedAction(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->batteryPressPowerBtnAction(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->batteryLidClosedAction(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->lowPowerNotifyEnable(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->lowPowerNotifyThreshold(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->lowPowerAutoSleepThreshold(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->getSuspend(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->getHibernate(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->getShutdown(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->getPowerPlan(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isHighPerformanceSupported(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->isBalancePerformanceSupported(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isNoPasswdLogin(); break;
        case 34: *reinterpret_cast<int*>(_v) = _t->batteryCapacity(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->showBatteryTimeToFull(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->scheduledShutdownState(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->shutdownTime(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->shutdownRepetition(); break;
        case 39: *reinterpret_cast<int*>(_v) = _t->weekBegins(); break;
        case 40: *reinterpret_cast<int*>(_v) = _t->lowPowerAction(); break;
        case 41: *reinterpret_cast<QVariantList*>(_v) = _t->customShutdownWeekDays(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->isVirtualEnvironment(); break;
        case 43: *reinterpret_cast<QVariantList*>(_v) = _t->batteryLockDelayModel(); break;
        case 44: *reinterpret_cast<QVariantList*>(_v) = _t->batteryScreenBlackDelayModel(); break;
        case 45: *reinterpret_cast<QVariantList*>(_v) = _t->batterySleepDelayModel(); break;
        case 46: *reinterpret_cast<QVariantList*>(_v) = _t->linePowerLockDelayModel(); break;
        case 47: *reinterpret_cast<QVariantList*>(_v) = _t->linePowerScreenBlackDelayModel(); break;
        case 48: *reinterpret_cast<QVariantList*>(_v) = _t->linePowerSleepDelayModel(); break;
        case 49: *reinterpret_cast<QString*>(_v) = _t->enableScheduledShutdown(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLidPresent(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSleepOnLidOnPowerClose(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSleepOnLidOnBatteryClose(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setScreenBlackLock(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setSleepLock(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCanSuspend(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCanHibernate(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setScreenBlackDelayOnPower(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setSleepDelayOnPower(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setScreenBlackDelayOnBattery(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setSleepDelayOnBattery(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setAutoPowerSaveMode(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setPowerSaveMode(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setHaveBettary(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setBatteryLockScreenDelay(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setPowerLockScreenDelay(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setPowerSavingModeAutoWhenQuantifyLow(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setPowerSavingModeAuto(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setPowerSavingModeLowerBrightnessThreshold(*reinterpret_cast<uint*>(_v)); break;
        case 19: _t->setPowerSavingModeAutoBatteryPercentage(*reinterpret_cast<uint*>(_v)); break;
        case 20: _t->setLinePowerPressPowerBtnAction(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setLinePowerLidClosedAction(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setBatteryPressPowerBtnAction(*reinterpret_cast<int*>(_v)); break;
        case 23: _t->setBatteryLidClosedAction(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setLowPowerNotifyEnable(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setLowPowerNotifyThreshold(*reinterpret_cast<int*>(_v)); break;
        case 26: _t->setLowPowerAutoSleepThreshold(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setSuspend(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setHibernate(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setShutdown(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setPowerPlan(*reinterpret_cast<QString*>(_v)); break;
        case 31: _t->setHighPerformanceSupported(*reinterpret_cast<bool*>(_v)); break;
        case 32: _t->setBalancePerformanceSupported(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setNoPasswdLogin(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setBatteryCapacity(*reinterpret_cast<int*>(_v)); break;
        case 35: _t->setShowBatteryTimeToFull(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setScheduledShutdownState(*reinterpret_cast<bool*>(_v)); break;
        case 37: _t->setShutdownTime(*reinterpret_cast<QString*>(_v)); break;
        case 38: _t->setShutdownRepetition(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setWeekBegins(*reinterpret_cast<int*>(_v)); break;
        case 40: _t->setLowPowerAction(*reinterpret_cast<int*>(_v)); break;
        case 41: _t->setCustomShutdownWeekDays(*reinterpret_cast<QVariantList*>(_v)); break;
        case 42: _t->setIsVirtualEnvironment(*reinterpret_cast<bool*>(_v)); break;
        case 43: _t->setBatteryLockDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 44: _t->setBatteryScreenBlackDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 45: _t->setBatterySleepDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 46: _t->setLinePowerLockDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 47: _t->setLinePowerScreenBlackDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 48: _t->setLinePowerSleepDelayModel(*reinterpret_cast<QVariantList*>(_v)); break;
        case 49: _t->setEnableScheduledShutdown(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PowerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 50)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 50)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 50;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    }
    return _id;
}

// SIGNAL 0
void PowerModel::sleepLockChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerModel::canSuspendChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerModel::screenBlackLockChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerModel::lidPresentChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerModel::sleepOnLidOnPowerCloseChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerModel::sleepOnLidOnBatteryCloseChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PowerModel::screenBlackDelayChangedOnPower(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PowerModel::sleepDelayChangedOnPower(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PowerModel::screenBlackDelayChangedOnBattery(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PowerModel::sleepDelayChangedOnBattery(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PowerModel::canHibernateChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PowerModel::hibernateChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PowerModel::shutdownChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PowerModel::autoPowerSavingModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void PowerModel::powerSaveModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void PowerModel::haveBettaryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PowerModel::batteryLockScreenDelayChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void PowerModel::powerLockScreenDelayChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void PowerModel::powerSavingModeAutoWhenQuantifyLowChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void PowerModel::powerSavingModeAutoChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void PowerModel::powerSavingModeLowerBrightnessThresholdChanged(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void PowerModel::powerSavingModeAutoBatteryPercentageChanged(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void PowerModel::linePowerPressPowerBtnActionChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void PowerModel::linePowerLidClosedActionChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void PowerModel::batteryPressPowerBtnActionChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void PowerModel::batteryLidClosedActionChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void PowerModel::lowPowerNotifyEnableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void PowerModel::lowPowerNotifyThresholdChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void PowerModel::lowPowerAutoSleepThresholdChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void PowerModel::suspendChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void PowerModel::powerPlanChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void PowerModel::highPerformaceSupportChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void PowerModel::noPasswdLoginChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void PowerModel::batteryCapacityChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void PowerModel::showBatteryTimeToFullChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void PowerModel::scheduledShutdownStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void PowerModel::shutdownTimeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void PowerModel::shutdownRepetitionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 37, nullptr, _t1);
}

// SIGNAL 38
void PowerModel::weekBeginsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}

// SIGNAL 39
void PowerModel::customShutdownWeekDaysChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void PowerModel::isVirtualEnvironmentChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void PowerModel::batteryLockDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void PowerModel::batteryScreenBlackDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 42, nullptr, _t1);
}

// SIGNAL 43
void PowerModel::batterySleepDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void PowerModel::linePowerLockDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 44, nullptr, _t1);
}

// SIGNAL 45
void PowerModel::linePowerScreenBlackDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1);
}

// SIGNAL 46
void PowerModel::linePowerSleepDelayModelChanged(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void PowerModel::lowPowerActionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void PowerModel::enableScheduledShutdownChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 48, nullptr, _t1);
}
QT_WARNING_POP
