/****************************************************************************
** Meta object code from reading C++ file 'usermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/usermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'usermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV259UserModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::UserModel::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV259UserModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::UserModel",
        "userAdded",
        "",
        "User*",
        "user",
        "userRemoved",
        "avatarChanged",
        "userId",
        "avatar",
        "autoLoginChanged",
        "enable",
        "quickLoginChanged",
        "nopasswdLoginChanged",
        "groupsChanged",
        "groups",
        "passwordModifyFinished",
        "exitCode",
        "errorTxt",
        "onlineChanged",
        "online",
        "userTypeChanged",
        "userType",
        "fullnameChanged",
        "fullname",
        "passwordAgeChanged",
        "age",
        "isJoinADDomainChanged",
        "isjoin",
        "isADUserLoginChanged",
        "isLogind",
        "allGroupsChange",
        "deleteUserSuccess",
        "autoLoginVisableChanged",
        "autoLogin",
        "quickLoginVisibleChanged",
        "quickLogin",
        "noPassWordLoginVisableChanged",
        "noPassword",
        "isCancelChanged",
        "adminCntChange",
        "adminCnt"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'userAdded'
        QtMocHelpers::SignalData<void(User *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'userRemoved'
        QtMocHelpers::SignalData<void(User *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'avatarChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'autoLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'quickLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'nopasswdLoginChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'groupsChanged'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 14 },
        }}),
        // Signal 'passwordModifyFinished'
        QtMocHelpers::SignalData<void(const QString &, const int, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'onlineChanged'
        QtMocHelpers::SignalData<void(const QString &, const bool &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 19 },
        }}),
        // Signal 'userTypeChanged'
        QtMocHelpers::SignalData<void(const QString &, const int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'fullnameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'passwordAgeChanged'
        QtMocHelpers::SignalData<void(const QString &, const int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 25 },
        }}),
        // Signal 'isJoinADDomainChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'isADUserLoginChanged'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'allGroupsChange'
        QtMocHelpers::SignalData<void(const QStringList &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'deleteUserSuccess'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoLoginVisableChanged'
        QtMocHelpers::SignalData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Signal 'quickLoginVisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Signal 'noPassWordLoginVisableChanged'
        QtMocHelpers::SignalData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Signal 'isCancelChanged'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adminCntChange'
        QtMocHelpers::SignalData<void(const int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UserModel, qt_meta_tag_ZN6dccV259UserModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::UserModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259UserModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259UserModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV259UserModelE_t>.metaTypes,
    nullptr
} };

void dccV25::UserModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UserModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->userAdded((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1]))); break;
        case 1: _t->userRemoved((*reinterpret_cast<std::add_pointer_t<User*>>(_a[1]))); break;
        case 2: _t->avatarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->autoLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->quickLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->nopasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->groupsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 7: _t->passwordModifyFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->onlineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->userTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->fullnameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->passwordAgeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->isJoinADDomainChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->isADUserLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->allGroupsChange((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 15: _t->deleteUserSuccess(); break;
        case 16: _t->autoLoginVisableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->quickLoginVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->noPassWordLoginVisableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->isCancelChanged(); break;
        case 20: _t->adminCntChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< User* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(User * )>(_a, &UserModel::userAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(User * )>(_a, &UserModel::userRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const QString & )>(_a, &UserModel::avatarChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , bool )>(_a, &UserModel::autoLoginChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , bool )>(_a, &UserModel::quickLoginChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , bool )>(_a, &UserModel::nopasswdLoginChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const QStringList & )>(_a, &UserModel::groupsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const int , const QString & )>(_a, &UserModel::passwordModifyFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const bool & ) const>(_a, &UserModel::onlineChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const int )>(_a, &UserModel::userTypeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const QString & )>(_a, &UserModel::fullnameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QString & , const int )>(_a, &UserModel::passwordAgeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(bool )>(_a, &UserModel::isJoinADDomainChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(bool )>(_a, &UserModel::isADUserLoginChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const QStringList & )>(_a, &UserModel::allGroupsChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)()>(_a, &UserModel::deleteUserSuccess, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(bool )>(_a, &UserModel::autoLoginVisableChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(bool )>(_a, &UserModel::quickLoginVisibleChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(bool )>(_a, &UserModel::noPassWordLoginVisableChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)()>(_a, &UserModel::isCancelChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UserModel::*)(const int )>(_a, &UserModel::adminCntChange, 20))
            return;
    }
}

const QMetaObject *dccV25::UserModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::UserModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV259UserModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::UserModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void dccV25::UserModel::userAdded(User * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::UserModel::userRemoved(User * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::UserModel::avatarChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dccV25::UserModel::autoLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dccV25::UserModel::quickLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void dccV25::UserModel::nopasswdLoginChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dccV25::UserModel::groupsChanged(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dccV25::UserModel::passwordModifyFinished(const QString & _t1, const int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void dccV25::UserModel::onlineChanged(const QString & _t1, const bool & _t2)const
{
    QMetaObject::activate<void>(const_cast< dccV25::UserModel *>(this), &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void dccV25::UserModel::userTypeChanged(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void dccV25::UserModel::fullnameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void dccV25::UserModel::passwordAgeChanged(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void dccV25::UserModel::isJoinADDomainChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dccV25::UserModel::isADUserLoginChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void dccV25::UserModel::allGroupsChange(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::UserModel::deleteUserSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void dccV25::UserModel::autoLoginVisableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dccV25::UserModel::quickLoginVisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dccV25::UserModel::noPassWordLoginVisableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void dccV25::UserModel::isCancelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void dccV25::UserModel::adminCntChange(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}
QT_WARNING_POP
