/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.desktopspec.ObjectManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef OBJECTMANAGER1INTERFACE_H
#define OBJECTMANAGER1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "types/am.h"

/*
 * Proxy class for interface org.desktopspec.DBus.ObjectManager
 */
class AppManager1ApplicationObjectManager: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.desktopspec.DBus.ObjectManager"; }

public:
    AppManager1ApplicationObjectManager(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~AppManager1ApplicationObjectManager();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<ObjectMap> GetManagedObjects()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetManagedObjects"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void InterfacesAdded(const QDBusObjectPath &object_path, ObjectInterfaceMap interfaces_and_properties);
    void InterfacesRemoved(const QDBusObjectPath &object_path, const QStringList &interfaces);
};

namespace org {
  namespace desktopspec {
    namespace DBus {
      using ObjectManager = ::AppManager1ApplicationObjectManager;
    }
  }
}

#endif
