/****************************************************************************
** Meta object code from reading C++ file 'user.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-accounts/operation/user.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'user.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV254UserE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::User::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV254UserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::User",
        "passwordModifyFinished",
        "",
        "exitCode",
        "errorTxt",
        "nameChanged",
        "name",
        "fullnameChanged",
        "currentAvatarChanged",
        "avatar",
        "autoLoginChanged",
        "autoLogin",
        "quickLoginChanged",
        "quickLogin",
        "avatarListChanged",
        "avatars",
        "groupsChanged",
        "groups",
        "onlineChanged",
        "online",
        "nopasswdLoginChanged",
        "nopasswdLogin",
        "isCurrentUserChanged",
        "isCurrentUser",
        "passwordStatusChanged",
        "password",
        "createdTimeChanged",
        "createtime",
        "userTypeChanged",
        "userType",
        "isPasswordExpiredChanged",
        "isExpired",
        "passwordAgeChanged",
        "age",
        "gidChanged",
        "gid",
        "passwordResetFinished",
        "errorText",
        "startResetPasswordReplied",
        "setSecurityQuestionsReplied",
        "startSecurityQuestionsCheckReplied",
        "QList<int>",
        "questios",
        "fullname"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'passwordModifyFinished'
        QtMocHelpers::SignalData<void(const int, const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'fullnameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'currentAvatarChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'autoLoginChanged'
        QtMocHelpers::SignalData<void(const bool) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'quickLoginChanged'
        QtMocHelpers::SignalData<void(const bool) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'avatarListChanged'
        QtMocHelpers::SignalData<void(const QList<QString> &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Signal 'groupsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Signal 'onlineChanged'
        QtMocHelpers::SignalData<void(const bool &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'nopasswdLoginChanged'
        QtMocHelpers::SignalData<void(const bool) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Signal 'isCurrentUserChanged'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'passwordStatusChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'createdTimeChanged'
        QtMocHelpers::SignalData<void(const quint64 &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 27 },
        }}),
        // Signal 'userTypeChanged'
        QtMocHelpers::SignalData<void(const int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'isPasswordExpiredChanged'
        QtMocHelpers::SignalData<void(const bool) const>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'passwordAgeChanged'
        QtMocHelpers::SignalData<void(const int) const>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Signal 'gidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Signal 'passwordResetFinished'
        QtMocHelpers::SignalData<void(const QString &) const>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Signal 'startResetPasswordReplied'
        QtMocHelpers::SignalData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Signal 'setSecurityQuestionsReplied'
        QtMocHelpers::SignalData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Signal 'startSecurityQuestionsCheckReplied'
        QtMocHelpers::SignalData<void(const QList<int> &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'fullname'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<User, qt_meta_tag_ZN6dccV254UserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::User::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV254UserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV254UserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV254UserE_t>.metaTypes,
    nullptr
} };

void dccV25::User::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<User *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->passwordModifyFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->fullnameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->currentAvatarChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->autoLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->quickLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->avatarListChanged((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 7: _t->groupsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->onlineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->nopasswdLoginChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->isCurrentUserChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->passwordStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->createdTimeChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 13: _t->userTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->isPasswordExpiredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->passwordAgeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->gidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->passwordResetFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->startResetPasswordReplied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->setSecurityQuestionsReplied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->startSecurityQuestionsCheckReplied((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int , const QString & ) const>(_a, &User::passwordModifyFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & ) const>(_a, &User::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & ) const>(_a, &User::fullnameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & ) const>(_a, &User::currentAvatarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool ) const>(_a, &User::autoLoginChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool ) const>(_a, &User::quickLoginChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QList<QString> & ) const>(_a, &User::avatarListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QStringList & ) const>(_a, &User::groupsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool & ) const>(_a, &User::onlineChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool ) const>(_a, &User::nopasswdLoginChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(bool )>(_a, &User::isCurrentUserChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & ) const>(_a, &User::passwordStatusChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const quint64 & )>(_a, &User::createdTimeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int )>(_a, &User::userTypeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const bool ) const>(_a, &User::isPasswordExpiredChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const int ) const>(_a, &User::passwordAgeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::gidChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & ) const>(_a, &User::passwordResetFinished, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::startResetPasswordReplied, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::setSecurityQuestionsReplied, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QList<int> & )>(_a, &User::startSecurityQuestionsCheckReplied, 20))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fullname(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFullname(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dccV25::User::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::User::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV254UserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::User::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dccV25::User::passwordModifyFinished(const int _t1, const QString & _t2)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dccV25::User::nameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::User::fullnameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::User::currentAvatarChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::User::autoLoginChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::User::quickLoginChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::User::avatarListChanged(const QList<QString> & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dccV25::User::groupsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dccV25::User::onlineChanged(const bool & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dccV25::User::nopasswdLoginChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::User::isCurrentUserChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dccV25::User::passwordStatusChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dccV25::User::createdTimeChanged(const quint64 & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dccV25::User::userTypeChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void dccV25::User::isPasswordExpiredChanged(const bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dccV25::User::passwordAgeChanged(const int _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dccV25::User::gidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dccV25::User::passwordResetFinished(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dccV25::User *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dccV25::User::startResetPasswordReplied(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void dccV25::User::setSecurityQuestionsReplied(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void dccV25::User::startSecurityQuestionsCheckReplied(const QList<int> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}
QT_WARNING_POP
