/****************************************************************************
** Meta object code from reading C++ file 'defappmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-defaultapp/operation/defappmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'defappmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DefAppModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DefAppModel::qt_create_metaobjectdata<qt_meta_tag_ZN11DefAppModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DefAppModel",
        "browser",
        "CategoryModel*",
        "",
        "mail",
        "text",
        "music",
        "video",
        "picture",
        "terminal",
        "getModBrowser",
        "Category*",
        "getModMail",
        "getModText",
        "getModMusic",
        "getModVideo",
        "getModPicture",
        "getModTerminal"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'browser'
        QtMocHelpers::SlotData<CategoryModel *() const>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'mail'
        QtMocHelpers::SlotData<CategoryModel *() const>(4, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'text'
        QtMocHelpers::SlotData<CategoryModel *() const>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'music'
        QtMocHelpers::SlotData<CategoryModel *() const>(6, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'video'
        QtMocHelpers::SlotData<CategoryModel *() const>(7, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'picture'
        QtMocHelpers::SlotData<CategoryModel *() const>(8, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'terminal'
        QtMocHelpers::SlotData<CategoryModel *() const>(9, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'getModBrowser'
        QtMocHelpers::SlotData<Category *() const>(10, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModMail'
        QtMocHelpers::SlotData<Category *() const>(12, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModText'
        QtMocHelpers::SlotData<Category *() const>(13, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModMusic'
        QtMocHelpers::SlotData<Category *() const>(14, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModVideo'
        QtMocHelpers::SlotData<Category *() const>(15, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModPicture'
        QtMocHelpers::SlotData<Category *() const>(16, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'getModTerminal'
        QtMocHelpers::SlotData<Category *() const>(17, 3, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DefAppModel, qt_meta_tag_ZN11DefAppModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DefAppModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DefAppModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DefAppModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DefAppModelE_t>.metaTypes,
    nullptr
} };

void DefAppModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DefAppModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { CategoryModel* _r = _t->browser();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 1: { CategoryModel* _r = _t->mail();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 2: { CategoryModel* _r = _t->text();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 3: { CategoryModel* _r = _t->music();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 4: { CategoryModel* _r = _t->video();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 5: { CategoryModel* _r = _t->picture();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 6: { CategoryModel* _r = _t->terminal();
            if (_a[0]) *reinterpret_cast<CategoryModel**>(_a[0]) = std::move(_r); }  break;
        case 7: { Category* _r = _t->getModBrowser();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 8: { Category* _r = _t->getModMail();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 9: { Category* _r = _t->getModText();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 10: { Category* _r = _t->getModMusic();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 11: { Category* _r = _t->getModVideo();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 12: { Category* _r = _t->getModPicture();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        case 13: { Category* _r = _t->getModTerminal();
            if (_a[0]) *reinterpret_cast<Category**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *DefAppModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DefAppModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DefAppModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DefAppModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
