/****************************************************************************
** Meta object code from reading C++ file 'treelandworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-personalization/operation/treelandworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'treelandworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14TreeLandWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto TreeLandWorker::qt_create_metaobjectdata<qt_meta_tag_ZN14TreeLandWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreeLandWorker",
        "wallpaperChanged",
        "",
        "ApppearanceThemeChanged",
        "id",
        "IconThemeChanged",
        "CursorThemeChanged",
        "onWallpaperUrlsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ApppearanceThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'IconThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'CursorThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'onWallpaperUrlsChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandWorker, qt_meta_tag_ZN14TreeLandWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreeLandWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<PersonalizationWorker::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TreeLandWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TreeLandWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TreeLandWorkerE_t>.metaTypes,
    nullptr
} };

void TreeLandWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wallpaperChanged(); break;
        case 1: _t->ApppearanceThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->IconThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->CursorThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->onWallpaperUrlsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TreeLandWorker::*)()>(_a, &TreeLandWorker::wallpaperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeLandWorker::*)(const QString & )>(_a, &TreeLandWorker::ApppearanceThemeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeLandWorker::*)(const QString & )>(_a, &TreeLandWorker::IconThemeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeLandWorker::*)(const QString & )>(_a, &TreeLandWorker::CursorThemeChanged, 3))
            return;
    }
}

const QMetaObject *TreeLandWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeLandWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TreeLandWorkerE_t>.strings))
        return static_cast<void*>(this);
    return PersonalizationWorker::qt_metacast(_clname);
}

int TreeLandWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PersonalizationWorker::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void TreeLandWorker::wallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TreeLandWorker::ApppearanceThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TreeLandWorker::IconThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TreeLandWorker::CursorThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN22PersonalizationManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationManager::qt_create_metaobjectdata<qt_meta_tag_ZN22PersonalizationManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationManager, qt_meta_tag_ZN22PersonalizationManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<PersonalizationManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22PersonalizationManagerE_t>.metaTypes,
    nullptr
} };

void PersonalizationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PersonalizationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PersonalizationManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_personalization_manager_v1"))
        return static_cast< QtWayland::treeland_personalization_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<PersonalizationManager>::qt_metacast(_clname);
}

int PersonalizationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<PersonalizationManager>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN32PersonalizationAppearanceContextE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationAppearanceContext::qt_create_metaobjectdata<qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationAppearanceContext"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationAppearanceContext, qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationAppearanceContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<PersonalizationAppearanceContext>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>.metaTypes,
    nullptr
} };

void PersonalizationAppearanceContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationAppearanceContext *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PersonalizationAppearanceContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationAppearanceContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PersonalizationAppearanceContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_personalization_appearance_context_v1"))
        return static_cast< QtWayland::treeland_personalization_appearance_context_v1*>(this);
    return QWaylandClientExtensionTemplate<PersonalizationAppearanceContext>::qt_metacast(_clname);
}

int PersonalizationAppearanceContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<PersonalizationAppearanceContext>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN28PersonalizationCursorContextE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationCursorContext::qt_create_metaobjectdata<qt_meta_tag_ZN28PersonalizationCursorContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationCursorContext"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationCursorContext, qt_meta_tag_ZN28PersonalizationCursorContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationCursorContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<PersonalizationCursorContext>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28PersonalizationCursorContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28PersonalizationCursorContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28PersonalizationCursorContextE_t>.metaTypes,
    nullptr
} };

void PersonalizationCursorContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationCursorContext *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PersonalizationCursorContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationCursorContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28PersonalizationCursorContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_personalization_cursor_context_v1"))
        return static_cast< QtWayland::treeland_personalization_cursor_context_v1*>(this);
    return QWaylandClientExtensionTemplate<PersonalizationCursorContext>::qt_metacast(_clname);
}

int PersonalizationCursorContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<PersonalizationCursorContext>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN26PersonalizationFontContextE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonalizationFontContext::qt_create_metaobjectdata<qt_meta_tag_ZN26PersonalizationFontContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonalizationFontContext"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonalizationFontContext, qt_meta_tag_ZN26PersonalizationFontContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonalizationFontContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<PersonalizationFontContext>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PersonalizationFontContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PersonalizationFontContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26PersonalizationFontContextE_t>.metaTypes,
    nullptr
} };

void PersonalizationFontContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonalizationFontContext *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PersonalizationFontContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonalizationFontContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PersonalizationFontContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_personalization_font_context_v1"))
        return static_cast< QtWayland::treeland_personalization_font_context_v1*>(this);
    return QWaylandClientExtensionTemplate<PersonalizationFontContext>::qt_metacast(_clname);
}

int PersonalizationFontContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<PersonalizationFontContext>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16WallpaperManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto WallpaperManager::qt_create_metaobjectdata<qt_meta_tag_ZN16WallpaperManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WallpaperManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperManager, qt_meta_tag_ZN16WallpaperManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WallpaperManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<WallpaperManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16WallpaperManagerE_t>.metaTypes,
    nullptr
} };

void WallpaperManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *WallpaperManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WallpaperManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_wallpaper_manager_v1"))
        return static_cast< QtWayland::treeland_wallpaper_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<WallpaperManager>::qt_metacast(_clname);
}

int WallpaperManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<WallpaperManager>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16WallpaperContextE_t {};
} // unnamed namespace

template <> constexpr inline auto WallpaperContext::qt_create_metaobjectdata<qt_meta_tag_ZN16WallpaperContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WallpaperContext",
        "wallpaperChanged",
        "",
        "wallpaper_role",
        "role",
        "wallpaper_source_type",
        "type",
        "fileSource",
        "wallpaperFailed",
        "uint32_t",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void(wallpaper_role, wallpaper_source_type, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'wallpaperFailed'
        QtMocHelpers::SignalData<void(const QString &, uint32_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperContext, qt_meta_tag_ZN16WallpaperContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WallpaperContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<WallpaperContext>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16WallpaperContextE_t>.metaTypes,
    nullptr
} };

void WallpaperContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wallpaperChanged((*reinterpret_cast<std::add_pointer_t<wallpaper_role>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<wallpaper_source_type>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->wallpaperFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperContext::*)(wallpaper_role , wallpaper_source_type , const QString & )>(_a, &WallpaperContext::wallpaperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperContext::*)(const QString & , uint32_t )>(_a, &WallpaperContext::wallpaperFailed, 1))
            return;
    }
}

const QMetaObject *WallpaperContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WallpaperContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WallpaperContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_wallpaper_v1"))
        return static_cast< QtWayland::treeland_wallpaper_v1*>(this);
    return QWaylandClientExtensionTemplate<WallpaperContext>::qt_metacast(_clname);
}

int WallpaperContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<WallpaperContext>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void WallpaperContext::wallpaperChanged(wallpaper_role _t1, wallpaper_source_type _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void WallpaperContext::wallpaperFailed(const QString & _t1, uint32_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
