/****************************************************************************
** Meta object code from reading C++ file 'bluetoothadapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-bluetooth/operation/bluetoothadapter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothadapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16BluetoothAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto BluetoothAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN16BluetoothAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluetoothAdapter",
        "nameChanged",
        "",
        "name",
        "deviceAdded",
        "const BluetoothDevice*",
        "device",
        "deviceRemoved",
        "deviceId",
        "poweredChanged",
        "powered",
        "discovering",
        "loadStatus",
        "discoverableChanged",
        "discoverable",
        "closeDetailPage",
        "myDeviceVisibleChanged",
        "id",
        "addDevice",
        "removeDevice",
        "onGetDevices",
        "replyStr",
        "onClearUnpairedDevice",
        "onSetAdapterPowered",
        "onSetAdapterPoweredError",
        "onDeviceStateChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const BluetoothDevice *) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'poweredChanged'
        QtMocHelpers::SignalData<void(const bool &, const bool &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'loadStatus'
        QtMocHelpers::SignalData<void() const>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void(const bool &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'closeDetailPage'
        QtMocHelpers::SignalData<void() const>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'myDeviceVisibleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'addDevice'
        QtMocHelpers::SlotData<void(const BluetoothDevice *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'removeDevice'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'onGetDevices'
        QtMocHelpers::SlotData<void(QString)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'onClearUnpairedDevice'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSetAdapterPowered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSetAdapterPoweredError'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDeviceStateChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BluetoothAdapter, qt_meta_tag_ZN16BluetoothAdapterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluetoothAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BluetoothAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BluetoothAdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16BluetoothAdapterE_t>.metaTypes,
    nullptr
} };

void BluetoothAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<const BluetoothDevice*>>(_a[1]))); break;
        case 2: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->poweredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->loadStatus(); break;
        case 5: _t->discoverableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->closeDetailPage(); break;
        case 7: _t->myDeviceVisibleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->addDevice((*reinterpret_cast<std::add_pointer_t<const BluetoothDevice*>>(_a[1]))); break;
        case 9: _t->removeDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->onGetDevices((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->onClearUnpairedDevice(); break;
        case 12: _t->onSetAdapterPowered(); break;
        case 13: _t->onSetAdapterPoweredError(); break;
        case 14: _t->onDeviceStateChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const QString & ) const>(_a, &BluetoothAdapter::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const BluetoothDevice * ) const>(_a, &BluetoothAdapter::deviceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const QString & ) const>(_a, &BluetoothAdapter::deviceRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const bool & , const bool & ) const>(_a, &BluetoothAdapter::poweredChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)() const>(_a, &BluetoothAdapter::loadStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const bool & ) const>(_a, &BluetoothAdapter::discoverableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)() const>(_a, &BluetoothAdapter::closeDetailPage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)(const QString & )>(_a, &BluetoothAdapter::myDeviceVisibleChanged, 7))
            return;
    }
}

const QMetaObject *BluetoothAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluetoothAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BluetoothAdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluetoothAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void BluetoothAdapter::nameChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluetoothAdapter::deviceAdded(const BluetoothDevice * _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluetoothAdapter::deviceRemoved(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluetoothAdapter::poweredChanged(const bool & _t1, const bool & _t2)const
{
    QMetaObject::activate<void>(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void BluetoothAdapter::loadStatus()const
{
    QMetaObject::activate(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BluetoothAdapter::discoverableChanged(const bool & _t1)const
{
    QMetaObject::activate<void>(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluetoothAdapter::closeDetailPage()const
{
    QMetaObject::activate(const_cast< BluetoothAdapter *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void BluetoothAdapter::myDeviceVisibleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
