/****************************************************************************
** Meta object code from reading C++ file 'keyboardmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-keyboard/operation/keyboardmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513KeyboardModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::KeyboardModel::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513KeyboardModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::KeyboardModel",
        "curLayoutChanged",
        "",
        "layout",
        "keyboardEnabledChanged",
        "value",
        "curLangChanged",
        "lang",
        "capsLockChanged",
        "numLockChanged",
        "repeatDelayChanged",
        "repeatIntervalChanged",
        "userLayoutChanged",
        "id",
        "langChanged",
        "QList<MetaData>",
        "data",
        "curLocalLangChanged",
        "localLangList",
        "onSetCurLangFinish",
        "setLayout",
        "key",
        "setLang",
        "setLocaleLang",
        "addUserLayout",
        "setLocaleList",
        "langList",
        "setCapsLock",
        "setAllShortcut",
        "QMap<QStringList,int>",
        "map",
        "setKeyboardEnabled",
        "keyboardEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'curLayoutChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'keyboardEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'curLangChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'capsLockChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'numLockChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'repeatDelayChanged'
        QtMocHelpers::SignalData<void(const uint)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'repeatIntervalChanged'
        QtMocHelpers::SignalData<void(const uint)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'userLayoutChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'langChanged'
        QtMocHelpers::SignalData<void(const QList<MetaData> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'curLocalLangChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 18 },
        }}),
        // Signal 'onSetCurLangFinish'
        QtMocHelpers::SignalData<void(const int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setLayout'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setLang'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setLocaleLang'
        QtMocHelpers::SlotData<void(const QStringList &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 18 },
        }}),
        // Slot 'addUserLayout'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'setLocaleList'
        QtMocHelpers::SlotData<void(const QList<MetaData> &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 26 },
        }}),
        // Slot 'setCapsLock'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setAllShortcut'
        QtMocHelpers::SlotData<void(const QMap<QStringList,int> &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setKeyboardEnabled'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardModel, qt_meta_tag_ZN6dccV2513KeyboardModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::KeyboardModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513KeyboardModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513KeyboardModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513KeyboardModelE_t>.metaTypes,
    nullptr
} };

void dccV25::KeyboardModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->curLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->keyboardEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->curLangChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->capsLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->numLockChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->repeatDelayChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->repeatIntervalChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->userLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->langChanged((*reinterpret_cast<std::add_pointer_t<QList<MetaData>>>(_a[1]))); break;
        case 9: _t->curLocalLangChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 10: _t->onSetCurLangFinish((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setLang((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->setLocaleLang((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 14: _t->addUserLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->setLocaleList((*reinterpret_cast<std::add_pointer_t<QList<MetaData>>>(_a[1]))); break;
        case 16: _t->setCapsLock((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setAllShortcut((*reinterpret_cast<std::add_pointer_t<QMap<QStringList,int>>>(_a[1]))); break;
        case 18: _t->setKeyboardEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const QString & )>(_a, &KeyboardModel::curLayoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(bool )>(_a, &KeyboardModel::keyboardEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const QString & )>(_a, &KeyboardModel::curLangChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(bool )>(_a, &KeyboardModel::capsLockChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(bool )>(_a, &KeyboardModel::numLockChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const uint )>(_a, &KeyboardModel::repeatDelayChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const uint )>(_a, &KeyboardModel::repeatIntervalChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const QString & , const QString & )>(_a, &KeyboardModel::userLayoutChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const QList<MetaData> & )>(_a, &KeyboardModel::langChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const QStringList & )>(_a, &KeyboardModel::curLocalLangChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardModel::*)(const int )>(_a, &KeyboardModel::onSetCurLangFinish, 10))
            return;
    }
}

const QMetaObject *dccV25::KeyboardModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::KeyboardModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513KeyboardModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::KeyboardModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void dccV25::KeyboardModel::curLayoutChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dccV25::KeyboardModel::keyboardEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::KeyboardModel::curLangChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::KeyboardModel::capsLockChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dccV25::KeyboardModel::numLockChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::KeyboardModel::repeatDelayChanged(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dccV25::KeyboardModel::repeatIntervalChanged(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dccV25::KeyboardModel::userLayoutChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void dccV25::KeyboardModel::langChanged(const QList<MetaData> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dccV25::KeyboardModel::curLocalLangChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dccV25::KeyboardModel::onSetCurLangFinish(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
