/****************************************************************************
** Meta object code from reading C++ file 'shortcutmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-datetime/operation/keyboard/shortcutmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'shortcutmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6dccV2513ShortcutModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dccV25::ShortcutModel::qt_create_metaobjectdata<qt_meta_tag_ZN6dccV2513ShortcutModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dccV25::ShortcutModel",
        "listChanged",
        "",
        "QList<ShortcutInfo*>",
        "InfoType",
        "addCustomInfo",
        "ShortcutInfo*",
        "info",
        "shortcutChanged",
        "keyEvent",
        "press",
        "shortcut",
        "searchFinished",
        "searchResult",
        "windowSwitchChanged",
        "value",
        "onParseInfo",
        "onCustomInfo",
        "json",
        "onKeyBindingChanged",
        "onWindowSwitchChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'listChanged'
        QtMocHelpers::SignalData<void(QList<ShortcutInfo*>, enum InfoType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'addCustomInfo'
        QtMocHelpers::SignalData<void(ShortcutInfo *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'shortcutChanged'
        QtMocHelpers::SignalData<void(ShortcutInfo *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'keyEvent'
        QtMocHelpers::SignalData<void(bool, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'searchFinished'
        QtMocHelpers::SignalData<void(const QList<ShortcutInfo*>)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 13 },
        }}),
        // Signal 'windowSwitchChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'onParseInfo'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'onCustomInfo'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'onKeyBindingChanged'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onWindowSwitchChanged'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShortcutModel, qt_meta_tag_ZN6dccV2513ShortcutModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dccV25::ShortcutModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513ShortcutModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513ShortcutModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6dccV2513ShortcutModelE_t>.metaTypes,
    nullptr
} };

void dccV25::ShortcutModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShortcutModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->listChanged((*reinterpret_cast<std::add_pointer_t<QList<ShortcutInfo*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum InfoType>>(_a[2]))); break;
        case 1: _t->addCustomInfo((*reinterpret_cast<std::add_pointer_t<ShortcutInfo*>>(_a[1]))); break;
        case 2: _t->shortcutChanged((*reinterpret_cast<std::add_pointer_t<ShortcutInfo*>>(_a[1]))); break;
        case 3: _t->keyEvent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->searchFinished((*reinterpret_cast<std::add_pointer_t<QList<ShortcutInfo*>>>(_a[1]))); break;
        case 5: _t->windowSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->onParseInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->onCustomInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->onKeyBindingChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->onWindowSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(QList<ShortcutInfo*> , InfoType )>(_a, &ShortcutModel::listChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(ShortcutInfo * )>(_a, &ShortcutModel::addCustomInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(ShortcutInfo * )>(_a, &ShortcutModel::shortcutChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(bool , const QString & )>(_a, &ShortcutModel::keyEvent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(const QList<ShortcutInfo*> )>(_a, &ShortcutModel::searchFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutModel::*)(bool )>(_a, &ShortcutModel::windowSwitchChanged, 5))
            return;
    }
}

const QMetaObject *dccV25::ShortcutModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dccV25::ShortcutModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6dccV2513ShortcutModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dccV25::ShortcutModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void dccV25::ShortcutModel::listChanged(QList<ShortcutInfo*> _t1, InfoType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dccV25::ShortcutModel::addCustomInfo(ShortcutInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dccV25::ShortcutModel::shortcutChanged(ShortcutInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dccV25::ShortcutModel::keyEvent(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dccV25::ShortcutModel::searchFinished(const QList<ShortcutInfo*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dccV25::ShortcutModel::windowSwitchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
