// This file is autogenerated. Changes will be overwritten.
#include "MTJHVBGFB2/moc_category.cpp"
#include "MTJHVBGFB2/moc_categorymodel.cpp"
#include "MTJHVBGFB2/moc_defappmodel.cpp"
#include "MTJHVBGFB2/moc_defappworker.cpp"
#include "MTJHVBGFB2/moc_defappworkerold.cpp"
#include "MTJHVBGFB2/moc_mimedbusproxy.cpp"
#include "MTJHVBGFB2/moc_mimedbusproxyold.cpp"
