/****************************************************************************
** Meta object code from reading C++ file 'defappworkerold.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-defaultapp/operation/defappworkerold.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'defappworkerold.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DefAppWorkerOldE_t {};
} // unnamed namespace

template <> constexpr inline auto DefAppWorkerOld::qt_create_metaobjectdata<qt_meta_tag_ZN15DefAppWorkerOldE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DefAppWorkerOld",
        "onSetDefaultApp",
        "",
        "category",
        "App",
        "item",
        "onGetListApps",
        "onDelUserApp",
        "mine",
        "onCreateFile",
        "mime",
        "QFileInfo",
        "info",
        "getListAppFinished",
        "defaultApp",
        "isUser",
        "getDefaultAppFinished",
        "w",
        "saveListApp",
        "QJsonArray",
        "json",
        "saveDefaultApp",
        "QJsonObject"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onSetDefaultApp'
        QtMocHelpers::SlotData<void(const QString &, const App &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onGetListApps'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDelUserApp'
        QtMocHelpers::SlotData<void(const QString &, const App &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onCreateFile'
        QtMocHelpers::SlotData<void(const QString &, const QFileInfo &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'getListAppFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'getDefaultAppFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'saveListApp'
        QtMocHelpers::SlotData<void(const QString &, const QJsonArray &, const bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 19, 20 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'saveDefaultApp'
        QtMocHelpers::SlotData<void(const QString &, const QJsonObject &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 22, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DefAppWorkerOld, qt_meta_tag_ZN15DefAppWorkerOldE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DefAppWorkerOld::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DefAppWorkerOldE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DefAppWorkerOldE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DefAppWorkerOldE_t>.metaTypes,
    nullptr
} };

void DefAppWorkerOld::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DefAppWorkerOld *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onSetDefaultApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<App>>(_a[2]))); break;
        case 1: _t->onGetListApps(); break;
        case 2: _t->onDelUserApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<App>>(_a[2]))); break;
        case 3: _t->onCreateFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2]))); break;
        case 4: _t->getListAppFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->getDefaultAppFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->saveListApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->saveDefaultApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *DefAppWorkerOld::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DefAppWorkerOld::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DefAppWorkerOldE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DefAppWorkerOld::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
